import datetime
import hashlib
import json
import os
import random
import re
import sqlite3
import string
import time
from shutil import copyfile

import requests
from aiohttp import ClientSession
from httpx import AsyncClient
from nonebot import logger

mhyVersion = '2.11.1'

BASE_PATH = os.path.dirname(__file__)
BASE2_PATH = os.path.join(BASE_PATH, 'mihoyo_bbs')
INDEX_PATH = os.path.join(BASE2_PATH, 'index')

async def config_check(func, mode='CHECK'):
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()
    c.execute("""CREATE TABLE IF NOT EXISTS Config
            (Name TEXT PRIMARY KEY     NOT NULL,
            Status      TEXT,
            GroupList   TEXT,
            Extra       TEXT);""")
    c.execute('INSERT OR IGNORE INTO Config (Name,Status) \
                            VALUES (?, ?)', (func, 'on'))
    if mode == 'CHECK':
        cursor = c.execute('SELECT * from Config WHERE Name = ?', (func,))
        c_data = cursor.fetchall()
        conn.close()
        if c_data[0][1] != 'off':
            return True
        else:
            return False
    elif mode == 'OPEN':
        c.execute('UPDATE Config SET Status = ? WHERE Name=?', ('on', func))
        conn.commit()
        conn.close()
        return True
    elif mode == 'CLOSED':
        c.execute('UPDATE Config SET Status = ? WHERE Name=?', ('off', func))
        conn.commit()
        conn.close()
        return True


async def get_a_lots(qid):
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()
    c.execute("""CREATE TABLE IF NOT EXISTS UseridDict
            (QID INT PRIMARY KEY     NOT NULL,
            lots        TEXT,
            cache       TEXT,
            permission  TEXT,
            Status      TEXT,
            Subscribe   TEXT,
            Extra       TEXT);""")
    cursor = c.execute('SELECT * from UseridDict WHERE QID = ?', (qid,))
    c_data = cursor.fetchall()
    with open(os.path.join(INDEX_PATH, 'lots.txt'), 'r') as f:
        raw_data = f.read()
        raw_data = raw_data.replace(' ', '').split('-')

    if len(c_data) == 0:
        num = random.randint(1, len(raw_data) - 1)
        data = raw_data[num]
        c.execute('INSERT OR IGNORE INTO UseridDict (QID,lots) \
                            VALUES (?, ?)', (qid, str(num)))
    else:
        if c_data[0][1] is None:
            num = random.randint(0, len(raw_data) - 1)
            data = raw_data[num]
            c.execute('UPDATE UseridDict SET lots = ? WHERE QID=?', (str(num), qid))
        else:
            num = int(c_data[0][1])
            data = raw_data[num]
    conn.commit()
    conn.close()
    return data


async def open_push(uid, qid, status, mode):
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()
    cursor = c.execute('SELECT * from NewCookiesTable WHERE UID = ?', (uid,))
    c_data = cursor.fetchall()
    if len(c_data) != 0:
        try:
            c.execute('UPDATE NewCookiesTable SET {s} = ?,QID = ? WHERE UID=?'.format(s=mode), (status, qid, uid))
            conn.commit()
            conn.close()
            return '成功！'
        except:
            return '未找到Ck绑定记录。'
    else:
        return '未找到Ck绑定记录。'


async def check_db():
    return_str = str()
    normal_num = 0
    invalid_str = ''
    invalid_list = []
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()
    cursor = c.execute('SELECT UID,Cookies,QID  from NewCookiesTable')
    c_data = cursor.fetchall()
    for row in c_data:
        try:
            aid = re.search(r'account_id=(\d*)', row[1])
            mihoyo_id_data = aid.group(0).split('=')
            mihoyo_id = mihoyo_id_data[1]
            mys_data = await get_mihoyo_bbs_info(mihoyo_id, row[1])
            for i in mys_data['data']['list']:
                if i['game_id'] != 2:
                    mys_data['data']['list'].remove(i)
            return_str = return_str + f'uid{row[0]}/mys{mihoyo_id}的Cookies是正常的！\n'
            normal_num += 1
        except:
            invalid_str = invalid_str + f'uid{row[0]}的Cookies是异常的！已删除该条Cookies！\n'
            return_str = return_str + f'uid{row[0]}的Cookies是异常的！已删除该条Cookies！\n'
            invalid_list.append([row[2], row[0]])
            c.execute('DELETE from NewCookiesTable where UID=?', (row[0],))
            try:
                c.execute('DELETE from CookiesCache where Cookies=?', (row[1],))
            except:
                pass
    if len(c_data) > 9:
        return_str = '正常Cookies数量：{}\n{}'.format(str(normal_num),
                                                    '失效cookies:\n' + invalid_str if invalid_str else '无失效Cookies')
    conn.commit()
    conn.close()
    return [return_str, invalid_list]


async def connect_db(userid, uid=None, mys=None):
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()
    c.execute("""CREATE TABLE IF NOT EXISTS UIDDATA
        (USERID INT PRIMARY KEY     NOT NULL,
        UID         TEXT,
        MYSID       TEXT);""")

    c.execute('INSERT OR IGNORE INTO UIDDATA (USERID,UID,MYSID) \
    VALUES (?, ?,?)', (userid, uid, mys))

    if uid:
        c.execute('UPDATE UIDDATA SET UID = ? WHERE USERID=?', (uid, userid))
    if mys:
        c.execute('UPDATE UIDDATA SET MYSID = ? WHERE USERID=?', (mys, userid))

    conn.commit()
    conn.close()


async def select_db(userid, mode='auto'):
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()
    cursor = c.execute('SELECT *  FROM UIDDATA WHERE USERID = ?', (userid,))
    for row in cursor:
        if mode == 'auto':
            if row[0]:
                if row[2]:
                    return [row[2], 3]
                elif row[1]:
                    return [row[1], 2]
                else:
                    return None
            else:
                return None
        elif mode == 'uid':
            return [row[1], 2]
        elif mode == 'mys':
            return [row[2], 3]


async def delete_cache():
    try:
        copyfile('ID_DATA.db', 'ID_DATA_bak.db')
        logger.info('————数据库成功备份————')
    except:
        logger.info('————数据库备份失败————')

    try:
        conn = sqlite3.connect('ID_DATA.db')
        c = conn.cursor()
        c.execute('DROP TABLE CookiesCache')
        c.execute('UPDATE NewCookiesTable SET Extra = ? WHERE Extra=?', (None, 'limit30'))
        c.execute("""CREATE TABLE IF NOT EXISTS CookiesCache
        (UID TEXT PRIMARY KEY,
        MYSID         TEXT,
        Cookies       TEXT);""")
        conn.commit()
        conn.close()
        logger.info('————UID查询缓存已清空————')
    except:
        logger.info('\nerror\n')

    try:
        conn = sqlite3.connect('ID_DATA.db')
        c = conn.cursor()
        c.execute('UPDATE UseridDict SET lots=NULL')
        conn.commit()
        conn.close()
        logger.info('————御神签缓存已清空————')
    except:
        logger.info('\nerror\n')


def error_db(ck, err):
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()
    if err == 'error':
        c.execute('UPDATE NewCookiesTable SET Extra = ? WHERE Cookies=?', ('error', ck))
    elif err == 'limit30':
        c.execute('UPDATE NewCookiesTable SET Extra = ? WHERE Cookies=?', ('limit30', ck))


def cache_db(uid, mode=1, mys=None):
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()
    c.execute("""CREATE TABLE IF NOT EXISTS CookiesCache
        (UID TEXT PRIMARY KEY,
        MYSID         TEXT,
        Cookies       TEXT);""")

    if mode == 1:
        if mys:
            cursor = c.execute('SELECT *  FROM CookiesCache WHERE MYSID = ?', (mys,))
        else:
            cursor = c.execute('SELECT *  FROM CookiesCache WHERE UID = ?', (uid,))
    else:
        cursor = c.execute('SELECT *  FROM CookiesCache WHERE MYSID = ?', (uid,))
    c_data = cursor.fetchall()

    if len(c_data) == 0:
        if mode == 2:
            conn.create_function('REGEXP', 2, regex_func)
            cursor = c.execute('SELECT *  FROM NewCookiesTable WHERE REGEXP(Cookies, ?)', (uid,))
            d_data = cursor.fetchall()

        else:
            cursor = c.execute('SELECT *  FROM NewCookiesTable WHERE UID = ?', (uid,))
            d_data = cursor.fetchall()

        if len(d_data) != 0:
            if d_data[0][7] != 'error':
                use = d_data[0][1]
                if mode == 1:
                    c.execute('INSERT OR IGNORE INTO CookiesCache (Cookies,UID) \
                            VALUES (?, ?)', (use, uid))
                elif mode == 2:
                    c.execute('INSERT OR IGNORE INTO CookiesCache (Cookies,MYSID) \
                            VALUES (?, ?)', (use, uid))
            else:
                cookies_row = c.execute('SELECT * FROM NewCookiesTable WHERE Extra IS NULL ORDER BY RANDOM() LIMIT 1')
                e_data = cookies_row.fetchall()
                if len(e_data) != 0:
                    if mode == 1:
                        c.execute('INSERT OR IGNORE INTO CookiesCache (Cookies,UID) \
                                VALUES (?, ?)', (e_data[0][1], uid))
                    elif mode == 2:
                        c.execute('INSERT OR IGNORE INTO CookiesCache (Cookies,MYSID) \
                                VALUES (?, ?)', (e_data[0][1], uid))
                    use = e_data[0][1]
                else:
                    return '没有可以使用的Cookies！'
        else:
            cookies_row = c.execute('SELECT * FROM NewCookiesTable WHERE Extra IS NULL ORDER BY RANDOM() LIMIT 1')
            e_data = cookies_row.fetchall()
            if len(e_data) != 0:
                if mode == 1:
                    c.execute('INSERT OR IGNORE INTO CookiesCache (Cookies,UID) \
                            VALUES (?, ?)', (e_data[0][1], uid))
                elif mode == 2:
                    c.execute('INSERT OR IGNORE INTO CookiesCache (Cookies,MYSID) \
                            VALUES (?, ?)', (e_data[0][1], uid))
                use = e_data[0][1]
            else:
                return '没有可以使用的Cookies！'
    else:
        use = c_data[0][2]
        if mys:
            try:
                c.execute('UPDATE CookiesCache SET UID = ? WHERE MYSID=?', (uid, mys))
            except:
                c.execute('UPDATE CookiesCache SET MYSID = ? WHERE UID=?', (mys, uid))

    conn.commit()
    conn.close()
    return use


def regex_func(value, patter):
    c_pattern = re.compile(r'account_id={}'.format(patter))
    return c_pattern.search(value) is not None


async def cookies_db(uid, cookies, qid):
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()

    c.execute("""CREATE TABLE IF NOT EXISTS NewCookiesTable
    (UID INT PRIMARY KEY     NOT NULL,
    Cookies         TEXT,
    QID         INT,
    StatusA     TEXT,
    StatusB     TEXT,
    StatusC     TEXT,
    NUM         INT,
    Extra       TEXT);""")

    cursor = c.execute('SELECT * from NewCookiesTable WHERE UID = ?', (uid,))
    c_data = cursor.fetchall()
    if len(c_data) == 0:
        c.execute('INSERT OR IGNORE INTO NewCookiesTable (Cookies,UID,StatusA,StatusB,StatusC,NUM,QID) \
            VALUES (?, ?,?,?,?,?,?)', (cookies, uid, 'off', 'off', 'off', 140, qid))
    else:
        c.execute('UPDATE NewCookiesTable SET Cookies = ? WHERE UID=?', (cookies, uid))

    conn.commit()
    conn.close()


async def stoken_db(s_cookies, uid):
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()
    columns = [i[1] for i in c.execute('PRAGMA table_info(NewCookiesTable)')]

    if 'Stoken' not in columns:
        c.execute('ALTER TABLE NewCookiesTable ADD COLUMN Stoken TEXT')

    c.execute('UPDATE NewCookiesTable SET Stoken = ? WHERE UID=?', (s_cookies, int(uid)))

    conn.commit()
    conn.close()


async def get_stoken(uid):
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()
    try:
        cursor = c.execute('SELECT *  FROM NewCookiesTable WHERE UID = ?', (uid,))
        c_data = cursor.fetchall()
        stoken = c_data[0][8]
    except:
        return

    return stoken


async def owner_cookies(uid):
    conn = sqlite3.connect('ID_DATA.db')
    c = conn.cursor()
    try:
        cursor = c.execute('SELECT *  FROM NewCookiesTable WHERE UID = ?', (uid,))
        c_data = cursor.fetchall()
        cookies = c_data[0][1]
    except:
        return

    return cookies


def random_hex(length):
    result = hex(random.randint(0, 16 ** length)).replace('0x', '').upper()
    if len(result) < length:
        result = '0' * (length - len(result)) + result
    return result


def md5(text):
    md5_func = hashlib.md5()
    md5_func.update(text.encode())
    return md5_func.hexdigest()


def old_version_get_ds_token(mysbbs=False):
    if mysbbs:
        n = 'fd3ykrh7o1j54g581upo1tvpam0dsgtf'
    else:
        n = 'h8w582wxwgqvahcdkpvdhbh2w9casgfl'
    i = str(int(time.time()))
    r = ''.join(random.sample(string.ascii_lowercase + string.digits, 6))
    c = md5('salt=' + n + '&t=' + i + '&r=' + r)
    return i + ',' + r + ',' + c


def get_ds_token(q='', b=None):
    if b:
        br = json.dumps(b)
    else:
        br = ''
    s = 'xV8v4Qu54lUKrEYFZkJhB8cuOh9Asafs'
    t = str(int(time.time()))
    r = str(random.randint(100000, 200000))
    c = md5('salt=' + s + '&t=' + t + '&r=' + r + '&b=' + br + '&q=' + q)
    return t + ',' + r + ',' + c


async def get_stoken_by_login_ticket(loginticket, mys_id):
    async with AsyncClient() as client:
        req = await client.get(
            url='https://api-takumi.mihoyo.com/auth/api/getMultiTokenByLoginTicket',
            params={
                'login_ticket': loginticket,
                'token_types' : '3',
                'uid'         : mys_id
            }
        )
    return req.json()


async def get_daily_data(uid, server_id='cn_gf01'):
    if uid[0] == '5':
        server_id = 'cn_qd01'
    try:
        async with AsyncClient() as client:
            req = await client.get(
                url='https://api-takumi.mihoyo.com/game_record/app/genshin/api/dailyNote',
                headers={
                    'DS'               : get_ds_token('role_id=' + uid + '&server=' + server_id),
                    'x-rpc-app_version': mhyVersion,
                    'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 ('
                                         'KHTML, like Gecko) miHoYoBBS/2.11.1',
                    'x-rpc-client_type': '5',
                    'Referer'          : 'https://webstatic.mihoyo.com/',
                    'Cookie'           : await owner_cookies(uid)},
                params={
                    'server' : server_id,
                    'role_id': uid
                }
            )
            data = json.loads(req.text)
        return data
    except requests.exceptions.SSLError:
        try:
            async with AsyncClient() as client:
                req = await client.get(
                    url='https://api-takumi-record.mihoyo.com/game_record/app/genshin/api/dailyNote',
                    headers={
                        'DS'               : get_ds_token('role_id=' + uid + '&server=' + server_id),
                        'x-rpc-app_version': mhyVersion,
                        'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 '
                                             '(KHTML, like Gecko) miHoYoBBS/2.11.1',
                        'x-rpc-client_type': '5',
                        'Referer'          : 'https://webstatic.mihoyo.com/',
                        'Cookie'           : await owner_cookies(uid)},
                    params={
                        'server' : server_id,
                        'role_id': uid
                    }
                )
            data = json.loads(req.text)
            return data
        except json.decoder.JSONDecodeError:
            logger.info('当前状态读取Api失败！')
    except Exception as e:
        logger.info('访问每日信息失败，请重试！')
        logger.info(e.with_traceback)


async def get_sign_list():
    try:
        async with AsyncClient() as client:
            req = await client.get(
                url='https://api-takumi.mihoyo.com/event/bbs_sign_reward/home',
                headers={
                    'x-rpc-app_version': mhyVersion,
                    'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 ('
                                         'KHTML, like Gecko) miHoYoBBS/2.11.1',
                    'x-rpc-client_type': '5',
                    'Referer'          : 'https://webstatic.mihoyo.com/'},
                params={
                    'act_id': 'e202009291139501'
                }
            )
            data = json.loads(req.text)
        return data
    except:
        logger.info('获取签到奖励列表失败，请重试')


async def get_sign_info(uid, server_id='cn_gf01'):
    if uid[0] == '5':
        server_id = 'cn_qd01'
    try:
        async with AsyncClient() as client:
            req = await client.get(
                url='https://api-takumi.mihoyo.com/event/bbs_sign_reward/info',
                headers={
                    'x-rpc-app_version': mhyVersion,
                    'Cookie'           : await owner_cookies(uid),
                    'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 ('
                                         'KHTML, like Gecko) miHoYoBBS/2.11.1',
                    'x-rpc-client_type': '5',
                    'Referer'          : 'https://webstatic.mihoyo.com/'},
                params={
                    'act_id': 'e202009291139501',
                    'region': server_id,
                    'uid'   : uid
                }
            )
            data = json.loads(req.text)
        return data
    except:
        logger.info('获取签到信息失败，请重试')


async def mihoyo_bbs_sign(uid, server_id='cn_gf01'):
    if uid[0] == '5':
        server_id = 'cn_qd01'
    try:
        req = requests.post(
            url='https://api-takumi.mihoyo.com/event/bbs_sign_reward/sign',
            headers={
                'User_Agent'       : 'Mozilla/5.0 (Linux; Android 10; MIX 2 Build/QKQ1.190825.002; wv) AppleWebKit/537.36 ('
                                     'KHTML, like Gecko) Version/4.0 Chrome/83.0.4103.101 Mobile Safari/537.36 '
                                     'miHoYoBBS/2.3.0',
                'Cookie'           : await owner_cookies(uid),
                'x-rpc-device_id'  : random_hex(32),
                'Origin'           : 'https://webstatic.mihoyo.com',
                'X_Requested_With' : 'com.mihoyo.hyperion',
                'DS'               : old_version_get_ds_token(),
                'x-rpc-client_type': '5',
                'Referer'          : 'https://webstatic.mihoyo.com/bbs/event/signin-ys/index.html?bbs_auth_required=true&act_id'
                                     '=e202009291139501&utm_source=bbs&utm_medium=mys&utm_campaign=icon',
                'x-rpc-app_version': '2.3.0'
            },
            json={'act_id': 'e202009291139501', 'uid': uid, 'region': server_id}
        )
        data2 = json.loads(req.text)
        return data2
    except:
        logger.info('签到失败，请重试')


async def get_award(uid, server_id='cn_gf01'):
    if uid[0] == '5':
        server_id = 'cn_qd01'
    try:
        async with AsyncClient() as client:
            req = await client.get(
                url='https://hk4e-api.mihoyo.com/event/ys_ledger/monthInfo',
                headers={
                    'x-rpc-app_version': mhyVersion,
                    'Cookie'           : await owner_cookies(uid),
                    'DS'               : old_version_get_ds_token(),
                    'x-rpc-device_id'  : random_hex(32),
                    'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 ('
                                         'KHTML, like Gecko) miHoYoBBS/2.11.1',
                    'x-rpc-client_type': '5',
                    'Referer'          : 'https://webstatic.mihoyo.com/'},
                params={
                    'act_id'                : 'e202009291139501',
                    'bind_region'           : server_id,
                    'bind_uid'              : uid,
                    'month'                 : '0',
                    'bbs_presentation_style': 'fullscreen',
                    'bbs_auth_required'     : True,
                    'utm_source'            : 'bbs',
                    'utm_medium'            : 'mys',
                    'utm_campaign'          : 'icon'
                }
            )
            data = json.loads(req.text)
        return data
    except:
        logger.info('访问失败，请重试！')
        # sys.exit(1)


async def get_info(uid, ck, server_id='cn_gf01'):
    if uid[0] == '5':
        server_id = 'cn_qd01'
    try:
        async with AsyncClient() as client:
            req = await client.get(
                url='https://api-takumi.mihoyo.com/game_record/app/genshin/api/index',
                headers={
                    'DS'               : get_ds_token('role_id=' + uid + '&server=' + server_id),
                    'x-rpc-app_version': mhyVersion,
                    'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 ('
                                         'KHTML, like Gecko) miHoYoBBS/2.11.1',
                    'x-rpc-client_type': '5',
                    'Referer'          : 'https://webstatic.mihoyo.com/',
                    'Cookie'           : ck},
                params={
                    'role_id': uid,
                    'server' : server_id
                }
            )
            data = json.loads(req.text)
        return data
    except requests.exceptions.SSLError:
        try:
            async with AsyncClient() as client:
                req = await client.get(
                    url='https://api-takumi-record.mihoyo.com/game_record/app/genshin/api/index',
                    headers={
                        'DS'               : get_ds_token('role_id=' + uid + '&server=' + server_id),
                        'x-rpc-app_version': mhyVersion,
                        'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 '
                                             '(KHTML, like Gecko) miHoYoBBS/2.11.1',
                        'x-rpc-client_type': '5',
                        'Referer'          : 'https://webstatic.mihoyo.com/',
                        'Cookie'           : ck},
                    params={
                        'role_id': uid,
                        'server' : server_id
                    }
                )
            data = json.loads(req.text)
            return data
        except json.decoder.JSONDecodeError:
            logger.info('米游社基础信息读取新Api失败！')
    except Exception as e:
        logger.info('米游社基础信息读取旧Api失败！')
        logger.info(e.with_traceback)


async def get_spiral_abyss_info(uid, ck, schedule_type='1', server_id='cn_gf01'):
    if uid[0] == '5':
        server_id = 'cn_qd01'
    try:
        async with AsyncClient() as client:
            req = await client.get(
                url='https://api-takumi.mihoyo.com/game_record/app/genshin/api/spiralAbyss',
                headers={
                    'DS'               : get_ds_token(
                        'role_id=' + uid + '&schedule_type=' + schedule_type + '&server=' + server_id),
                    'Origin'           : 'https://webstatic.mihoyo.com',
                    'Cookie'           : ck,
                    'x-rpc-app_version': mhyVersion,
                    'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS '
                                         'X) AppleWebKit/605.1.15 (KHTML, like Gecko) miHoYoBBS/2.11.1',
                    'x-rpc-client_type': '5',
                    'Referer'          : 'https://webstatic.mihoyo.com/'
                },
                params={
                    'schedule_type': schedule_type,
                    'role_id'      : uid,
                    'server'       : server_id
                }
            )
            data = json.loads(req.text)
        return data
    except requests.exceptions.SSLError:
        try:
            async with AsyncClient() as client:
                req = await client.get(
                    url='https://api-takumi-record.mihoyo.com/game_record/app/genshin/api/spiralAbyss',
                    headers={
                        'DS'               : get_ds_token(
                            'role_id=' + uid + '&schedule_type=' + schedule_type + '&server=' + server_id),
                        'Origin'           : 'https://webstatic.mihoyo.com',
                        'Cookie'           : ck,
                        'x-rpc-app_version': mhyVersion,
                        'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 '
                                             '(KHTML, like Gecko) miHoYoBBS/2.11.1',
                        'x-rpc-client_type': '5',
                        'Referer'          : 'https://webstatic.mihoyo.com/'
                    },
                    params={
                        'role_id'               : uid,
                        'server'                : server_id,
                        'bbs_presentation_style': 'fullscreen',
                        'bbs_auth_required'     : 'true',
                        'utm_source'            : 'bbs',
                        'utm_medium'            : 'mys',
                        'utm_campaign'          : 'icon'
                    }
                )
            data = json.loads(req.text)
            return data
        except json.decoder.JSONDecodeError:
            logger.info('深渊信息读取新Api失败！')
    except Exception as e:
        logger.info('深渊信息读取老Api失败！')
        logger.info(e.with_traceback)


def get_character(uid, character_ids, ck, server_id='cn_gf01'):
    if uid[0] == '5':
        server_id = 'cn_qd01'
    try:
        req = requests.post(
            url='https://api-takumi.mihoyo.com/game_record/app/genshin/api/character',
            headers={
                'DS'               : get_ds_token('', {'character_ids': character_ids, 'role_id': uid,
                                                       'server'       : server_id}),
                'Origin'           : 'https://webstatic.mihoyo.com',
                'Cookie'           : ck,
                'x-rpc-app_version': mhyVersion,
                'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, '
                                     'like Gecko) miHoYoBBS/2.11.1',
                'x-rpc-client_type': '5',
                'Referer'          : 'https://webstatic.mihoyo.com/'
            },
            json={'character_ids': character_ids, 'role_id': uid, 'server': server_id}
        )
        data2 = json.loads(req.text)
        return data2
    except requests.exceptions.SSLError:
        try:
            req = requests.post(
                url='https://api-takumi-record.mihoyo.com/game_record/app/genshin/api/character',
                headers={
                    'DS'               : get_ds_token('', {'character_ids': character_ids, 'role_id': uid,
                                                           'server'       : server_id}),
                    'Origin'           : 'https://webstatic.mihoyo.com',
                    'Cookie'           : ck,
                    'x-rpc-app_version': mhyVersion,
                    'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 ('
                                         'KHTML, like Gecko) miHoYoBBS/2.11.1',
                    'x-rpc-client_type': '5',
                    'Referer'          : 'https://webstatic.mihoyo.com/'
                },
                json={'character_ids': character_ids, 'role_id': uid, 'server': server_id}
            )
            data = json.loads(req.text)
            return data
        except json.decoder.JSONDecodeError:
            logger.info('深渊信息读取新Api失败！')
    except Exception as e:
        logger.info('深渊信息读取老Api失败！')
        logger.info(e.with_traceback)


async def get_calculate_info(client: ClientSession, uid, char_id, ck, name, server_id='cn_gf01'):
    if uid[0] == '5':
        server_id = 'cn_qd01'
    url = 'https://api-takumi.mihoyo.com/event/e20200928calculate/v1/sync/avatar/detail'
    req = await client.get(
        url=url,
        headers={
            'DS'               : get_ds_token('uid={}&avatar_id={}&region={}'.format(uid, char_id, server_id)),
            'x-rpc-app_version': mhyVersion,
            'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 ('
                                 'KHTML, like Gecko) miHoYoBBS/2.11.1',
            'x-rpc-client_type': '5',
            'Referer'          : 'https://webstatic.mihoyo.com/',
            'Cookie'           : ck},
        params={
            'avatar_id': char_id,
            'uid'      : uid,
            'region'   : server_id
        }
    )
    data = await req.json()
    data.update({'name': name})
    return data


async def get_mihoyo_bbs_info(mysid, ck):
    try:
        async with AsyncClient() as client:
            req = await client.get(
                url='https://api-takumi.mihoyo.com/game_record/card/wapi/getGameRecordCard',
                headers={
                    'DS'               : get_ds_token('uid=' + mysid),
                    'x-rpc-app_version': mhyVersion,
                    'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 ('
                                         'KHTML, like Gecko) miHoYoBBS/2.11.1',
                    'x-rpc-client_type': '5',
                    'Referer'          : 'https://webstatic.mihoyo.com/',
                    'Cookie'           : ck},
                params={'uid': mysid}
            )
            data = json.loads(req.text)
        return data
    except requests.exceptions.SSLError:
        try:
            async with AsyncClient() as client:
                req = await client.get(
                    url='https://api-takumi-record.mihoyo.com/game_record/card/wapi/getGameRecordCard?uid=' + mysid,
                    headers={
                        'DS'               : get_ds_token('uid=' + mysid),
                        'x-rpc-app_version': mhyVersion,
                        'User-Agent'       : 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 '
                                             '(KHTML, like Gecko) miHoYoBBS/2.11.1',
                        'x-rpc-client_type': '5',
                        'Referer'          : 'https://webstatic.mihoyo.com/',
                        'Cookie'           : ck},
                    params={'uid': mysid}
                )
                data = json.loads(req.text)
            return data
        except json.decoder.JSONDecodeError:
            logger.info('米游社信息读取新Api失败！')
    except Exception as e:
        logger.info('米游社信息读取老Api失败！')
        logger.info(e.with_traceback)


async def get_audio_info(name, audioid, language='cn'):
    url = 'https://genshin.minigg.cn/'
    async with AsyncClient() as client:
        req = await client.get(
            url=url,
            headers={
                'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
                              'Chrome/95.0.4638.69 Safari/537.36',
                'Referer'   : 'https://genshin.minigg.cn/index.html'},
            params={'characters': name, 'audioid': audioid, 'language': language}
        )
    return req.text


async def get_weapon_info(name, level=None):
    if level:
        params = {'query': name, 'stats': level}
    else:
        params = {'query': name}
    async with AsyncClient() as client:
        req = await client.get(
            url='https://info.minigg.cn/weapons',
            headers={
                'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
                              'Chrome/95.0.4638.69 Safari/537.36'},
            params=params
        )
    data = json.loads(req.text)
    return data


async def get_misc_info(mode, name):
    url = 'https://info.minigg.cn/{}'.format(mode)
    async with AsyncClient() as client:
        req = await client.get(
            url=url,
            headers={
                'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
                              'Chrome/97.0.4692.71 Safari/537.36'},
            params={'query': name}
        )
    data = json.loads(req.text)
    return data


async def get_char_info(name, mode='char', level=None):
    url2 = None
    url3 = None
    data2 = None
    baseurl = 'https://info.minigg.cn/characters?query='
    if mode == 'talents':
        url = 'https://info.minigg.cn/talents?query=' + name
    elif mode == 'constellations':
        url = 'https://info.minigg.cn/constellations?query=' + name
    elif mode == 'costs':
        url = baseurl + name + '&costs=1'
        url2 = 'https://info.minigg.cn/talents?query=' + name + '&costs=1'
        url3 = 'https://info.minigg.cn/talents?query=' + name + '&matchCategories=true'
    elif level:
        url = baseurl + name + '&stats=' + level
    else:
        url = baseurl + name

    if url2:
        async with AsyncClient() as client:
            req = await client.get(
                url=url2,
                headers={
                    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
                                  'Chrome/95.0.4638.69 Safari/537.36',
                    'Referer'   : 'https://genshin.minigg.cn/index.html'})
            data2 = json.loads(req.text)
            if 'errcode' in data2:
                async with AsyncClient() as client_:
                    req = await client_.get(
                        url=url3,
                        headers={
                            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, '
                                          'like Gecko) Chrome/95.0.4638.69 Safari/537.36',
                            'Referer'   : 'https://genshin.minigg.cn/index.html'})
                    data2 = json.loads(req.text)

    async with AsyncClient() as client:
        req = await client.get(
            url=url,
            headers={
                'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
                              'Chrome/95.0.4638.69 Safari/537.36',
                'Referer'   : 'https://genshin.minigg.cn/index.html'})
        try:
            data = json.loads(req.text)
            if 'errcode' in data:
                async with AsyncClient() as client_:
                    req = await client_.get(
                        url=url + '&matchCategories=true',
                        headers={
                            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, '
                                          'like Gecko) Chrome/95.0.4638.69 Safari/537.36',
                            'Referer'   : 'https://genshin.minigg.cn/index.html'})
                    data = json.loads(req.text)
        except:
            data = None
    return data if data2 is None else [data, data2]


async def get_genshin_events(mode='List'):
    if mode == 'Calendar':
        now_time = datetime.datetime.now().strftime('%Y-%m-%d')
        base_url = 'https://api-takumi.mihoyo.com/event/bbs_activity_calendar/getActList'
        params = {
            'time'    : now_time,
            'game_biz': 'ys_cn',
            'page'    : 1,
            'tag_id'  : 0
        }
    else:
        base_url = 'https://hk4e-api.mihoyo.com/common/hk4e_cn/announcement/api/getAnn{}'.format(mode)
        params = {
            'game'     : 'hk4e',
            'game_biz' : 'hk4e_cn',
            'lang'     : 'zh-cn',
            'bundle_id': 'hk4e_cn',
            'platform' : 'pc',
            'region'   : 'cn_gf01',
            'level'    : 55,
            'uid'      : 100000000
        }

    async with AsyncClient() as client:
        req = await client.get(
            url=base_url,
            headers={
                'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
                              'Chrome/95.0.4638.69 Safari/537.36'},
            params=params
        )
    data = json.loads(req.text)
    return data



import requests
import time
import hashlib
md5 = hashlib.md5()
# 7fbc63b1c4e2af910d3466be857c9d25
# 1612610100
# 1612610200

ran = range(1612610000, 1612610227)
for x in ran:
	for y in range(0,9):
		for z in range(0,9):
			for m in range(0,9):
				for n in range(0,9):
					md5.update('{}.{}{}{}{}'.format(x,y,z,m,n).encode('utf-8'))
					if md5.hexdigest()=='7fbc63b1c4e2af910d3466be857c9d25':
						print(x,'.',y,z,m,n)
				# print(md5.hexdigest())

for x in ran:
	for y in range(0,9):
		md5.update('{}.{}'.format(x,y).encode('utf-8'))
		if md5.hexdigest()=='7fbc63b1c4e2af910d3466be857c9d25':
			print(x,'.',y)

for x in ran:
	md5.update('{}'.format(x).encode('utf-8'))
	if md5.hexdigest()=='7fbc63b1c4e2af910d3466be857c9d25':
		print(x)


def call():
	url = "https://{}/api/login".format('210.140.131.206')
	user_id = '37265945'
	timestamp = time.time()
	# print(time.time())
	md5.update(format(time.time(),'.1f').encode('utf-8'))
	post_key = md5.hexdigest()
	print("post_key",post_key)
	Cookies = """p_ab_id=4;
	p_ab_id_2=5;
	p_ab_d_id=1503173602;
	__utma=235335808.867814591.1612518455.1612518455.{};
	__utmb=235335808.2.10.{};
	__utmc=235335808; 
	__utmz=235335808.1612518455.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none); 
	__utmv=235335808.|2=login%20ever=no=1^3=plan=normal=1^5=gender=male=1^6=user_id=${}=1^9=p_ab_id=4=1^10=p_ab_id_2=5=1^11=lang=zh=1; 
	_ga=GA1.2.867814591.1612518455; 
	_gid=GA1.2.614123860.1612518483; 
	_ga=GA1.3.867814591.1612518455; 
	_gid=GA1.3.614123860.1. 612518483; 
	device_token=46308907811d508b5cd9b728c0c225be; 
	privacy_policy_agreement=2; 
	c_type=17; 
	a_type=0; 
	b_type=1; 
	__utmt=1; 
	PHPSESSID=mes21k640pi5pnrj9kdhj0u6c6oj0m8g""".format(format(timestamp,'.1f'),format(timestamp,'.0f'),user_id).replace('\n','')
	print(Cookies)
	headers = {
		"Host":"accounts.pixiv.net",
		"User-Agent":"Mozilla/5.0 (Macintosh; Intel Mac OS X 10.14; rv:82.0) Gecko/20100101 Firefox/82.0",
		"Accept":"application/json",
		"Accept-Language":"zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
		"Accept-Encoding":"gzip, deflate, br",
		"Referer":"https://accounts.pixiv.net/login?return_to=https%3A%2F%2Fwww.pixiv.net%2F&lang=zh&source=pc&view_type=page",
		"Content-Type":"application/x-www-form-urlencoded",
		"Origin":"https://accounts.pixiv.net",
		"Content-Length":"1699",
		"Connection":"keep-alive"
		# "Cookies": Cookies
	}

	data = {
		"password":"ldhllzLLZ-520",
		"pixiv_id":"122527455%40qq.com",
		"post_key":post_key,# 4bbe71e493eb1ae14ae7efd8c2007a9b
		"source":"pc",
		"return_to":"https%3A%2F%2Fwww.pixiv.net%2F&"
	}
	print(time.time())
	x = requests.post(url, headers=headers, data=data, verify=False)
	print(time.time())
	print(x)
	print(x.text)


call()



import requests as rq
import simplim

url = 'http://fanyi.youdao.com/translate'
def translate(words='', doctype='json', type_='AUTO'):
	if not words:
		return 'None'
	words = simplim.filtemoji(words)
	params = {
		'doctype':doctype,
		'type': type_,
		'i': words
	}
	res = rq.get(url,params=params).json()
	if res['errorCode'] == 0:
		return res['translateResult'][0][0]['tgt']
	return -1

def translate_list(words='', doctype='json', type_='AUTO'):
	if not words:
		return 'None'
	results = []
	for word in words:
		results.append(translate(u''+simplim.filtemoji(word)))
	return results

# def get_params(words='', doctype='json', type_='AUTO'):
# 	params = {
# 		'doctype':doctype,
# 		'type': type_,
# 		'i': words
# 	}
# 	return params

# def get(params):
# 	return rq.get(url,params=params).json()


'''
{
	"returnPhrase": ["test"],
	"query": "test",
	"errorCode": "0",
	"l": "en2zh-CHS",
	"tSpeakUrl": "https://openapi.youdao.com/ttsapi?q=%E6%B5%8B%E8%AF%95&langType=zh-CHS&sign=C35E73F8BF03EB895783547A4115915F&salt=1648336282769&voice=4&format=mp3&appKey=2423360539ba5632&ttsVoiceStrict=false",
	"web": [{
		"value": ["测试", "测验", "试验", "考试"],
		"key": "Test"
	}, {
		"value": ["测试用例", "测试个案", "测试案例", "测试实例"],
		"key": "Test case"
	}, {
		"value": ["图灵测试", "杜林测试", "图林测试"],
		"key": "Turing test"
	}],
	"requestId": "6ed02748-329a-4ec3-8c1b-b3616887c555",
	"translation": ["测试"],
	"dict": {
		"url": "yddict://m.youdao.com/dict?le=eng&q=test"
	},
	"webdict": {
		"url": "http://mobile.youdao.com/dict?le=eng&q=test"
	},
	"basic": {
		"exam_type": ["初中", "高中", "CET4", "CET6", "考研"],
		"us-phonetic": "test",
		"phonetic": "test",
		"uk-phonetic": "test",
		"wfs": [{
			"wf": {
				"name": "复数",
				"value": "tests"
			}
		}, {
			"wf": {
				"name": "第三人称单数",
				"value": "tests"
			}
		}, {
			"wf": {
				"name": "现在分词",
				"value": "testing"
			}
		}, {
			"wf": {
				"name": "过去式",
				"value": "tested"
			}
		}, {
			"wf": {
				"name": "过去分词",
				"value": "tested"
			}
		}],
		"uk-speech": "https://openapi.youdao.com/ttsapi?q=test&langType=en&sign=50658FCD5391F844F6A8FE3F3A1A18CC&salt=1648336282769&voice=5&format=mp3&appKey=2423360539ba5632&ttsVoiceStrict=false",
		"explains": ["n. （书面或口头的）测验，考试；（医疗上的）检查，化验，检验；（对机器或武器等的）试验，检验；（对水、土壤、空气等的）检测，检验；（衡量能力或技能等的）测试，考验；医疗检查设备；化验结果；（常指板球、橄榄球的）国际锦标赛（Test）；准则，标准；（冶）烤钵，灰皿；（一些无脊椎动物和原生动物的）甲壳", "v. 试验，测试；测验，考查（熟练程度，知识）；检测，检验（质量或含量）；检查（身体），（用试剂）化验；考验；尝，（触）试"],
		"us-speech": "https://openapi.youdao.com/ttsapi?q=test&langType=en&sign=50658FCD5391F844F6A8FE3F3A1A18CC&salt=1648336282769&voice=6&format=mp3&appKey=2423360539ba5632&ttsVoiceStrict=false"
	},
	"isWord": true,
	"speakUrl": "https://openapi.youdao.com/ttsapi?q=test&langType=en&sign=50658FCD5391F844F6A8FE3F3A1A18CC&salt=1648336282769&voice=4&format=mp3&appKey=2423360539ba5632&ttsVoiceStrict=false"
}
'''
url2 = 'https://aidemo.youdao.com/trans'
def translate2(words='',From='Auto',to='Auto'):
	if not words:
		return 'None'
	try:
		headers = {
			'origin': 'https://ai.youdao.com',
			'referer': 'https://ai.youdao.com/',
			'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.4844.51 Safari/537.36'
		}
		data = {
			'q': words,
			'from': From,
			'to': to
		}
		res = rq.post(url2,data=data,headers=headers).json()
		return res['translation'][0]
	except Exception as e:
		print(e)
		return 'None'





# import threading
import inspect
import ctypes
 
 
def _async_raise(tid, exctype):
	"""raises the exception, performs cleanup if needed"""
	tid = ctypes.c_long(tid)
	if not inspect.isclass(exctype):
		exctype = type(exctype)
	res = ctypes.pythonapi.PyThreadState_SetAsyncExc(tid, ctypes.py_object(exctype))
	if res == 0:
		raise ValueError("invalid thread id")
	elif res != 1:
		# """if it returns a number greater than one, you're in trouble,
		# and you should call it again with exc=NULL to revert the effect"""
		ctypes.pythonapi.PyThreadState_SetAsyncExc(tid, None)
		raise SystemError("PyThreadState_SetAsyncExc failed")


def stop_thread(thread):
	_async_raise(thread.ident, SystemExit)




r"""©2020 HARDRELICE. All Rights Reserved.
 ╻ ╻ ┏━┓ ┏━┓ ┏━┓ ┏━┓ ┏━╸ ╻   ╻  ┏━╸ ┏━╸ TM
 ┣━┫ ┣━┫ ┣━┛ ┃ ┃ ┣━┛ ┣━╸ ┃   ┃  ┃   ┣━╸
 ╹ ╹ ╹ ╹ ╹ ╹ ┗━┛ ╹ ╹ ┗━╸ ┗━╸ ╹  ┗━╸ ┗━╸

A tool using api <https://api.imjad.cn/pixiv/v1/> & <https://api.imjad.cn/pixiv/v2/> to search & download pic from Pixiv
"""

import simplim.api.translate.youdao as yd
from pathlib import Path
import requests as rq
import random
import json
import time
import simplim
import os

module_path = os.path.join(os.path.dirname(__file__), '')
# lost = open(os.path.join(module_path,'lost.png'),'rb').read()
lost = b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x02<\x00\x00\x00\xea\x08\x06\x00\x00\x00\xa6\xf7\x9f\x81\x00\x00\x0c)iCCPICC Profile\x00\x00H\x89\x95W\x07XS\xc9\x16\x9e[\x92\x90\x90\xd0\x02\x11\x90\x12z\x13Ez\x91\x1aZ\x00\x01\xa9\x82\x8d\x90\x04\x12J\x88\tA\xc4\x8e.*\xb8\x16TD\xb1\xa2\xab"\x8a\xae\x05\x90\xc5\x86]Y\x04\xec\xf5\x81\x8a\x8a\xb2.\x16l\xa8\xbcI\x02\xe8\xea\xf7\xde\xfb\xde\xf9\xbe\xb9\xf7\xbfg\xce\x9c\xf3\x9fsg\xe6\x9b\x01@=\x9a#\x16g\xa1\x1a\x00d\x8br%1!\x01\xcc\x89I\xc9L\xd2c@\x00\x0c@\x04\xc6\x80\xc4\xe1J\xc5\xfe\xd1\xd1\x11\x00\xca\xd0\xfb\x9f\xf2\xee\x06@\xe4\xef\xab\xf6r_?\xf7\xffW\xd1\xe4\xf1\xa5\\\x00\x90h\x88SyRn6\xc4\x87\x01\xc0]\xb9bI.\x00\x84\x1e\xa87\x9b\x91+\x86\x98\x08Y\x02m\t$\x08\xb1\xb9\x1c\xa7+\xb1\xbb\x1c\xa7*q\x84\xc2&.\x86\x05q\n\x00*T\x0eG\x92\x0e\x80\x9a\x9c\x173\x8f\x9b\x0e\xfd\xa8-\x83\xd8A\xc4\x13\x8a n\x84\xd8\x87+\xe0\xf0 \xfe\x0c\xf1\xa8\xec\xec\x1c\x88\xd5\xad!\xb6N\xfd\xceO\xfa?|\xa6\x0e\xfb\xe4p\xd2\x87\xb12\x17\x85\xa8\x04\n\xa5\xe2,\xce\xcc\xff\xb3\x1c\xff[\xb2\xb3dC1\xcc`\xa3\n$\xa11\xf2\x9c\xe5u\xcb\xcc\t\x97c*\xc4\x17D\xa9\x91Q\x10kA|M\xc8S\xd8\xcb\xf1\x13\x81,4~\xd0\xfe\x03W\xca\x825\x83\x7f\x1a\xa0T\x1e\'0\x1cb\x03\x88MEY\x91\x11\x83z\x9f4a0\x1bbX{4N\x98\xcb\x8eS\x8eEy\x92\x9c\x98A\xffh>_\x1a\x14;\x849\x12E,\xb9M\xb1,3\xde\x7f\xd0\xe7f\x01\x9f=\xe4\xb3\xa1@\x10\x97\xa8\xe4\x89\xb6\xe6\t\x13"!V\x83\xf8\x9e436|\xd0\xe6y\x81\x80\x159d#\x91\xc5\xc89\xc3\x7f\x8e\x814Ip\x8c\xd2\x063\xcf\x96\x0e\xe5\x85y\n\x84\xec\xc8A\x1c\x91+\x88\x0bU\x8e\xc5\xa6r9\nn\xba\x10g\xf0\xa5\x13#\x86x\xf2\xf8\x81A\xca\xbc\xb0B\xbe(~\x90?V*\xce\r\x88\x19\xb4\xdf!\xce\x8a\x1e\xb4\xc7\x1a\xf9Y!r\xbd)\xc4-\xd2\xbc\xd8\xa1\xb1\xbd\xb9p\xb2)\xf3\xc5\x8187:N\xc9\r\xd7\xce\xe0\x84E+9\xe0\xb6 \x02\xb0@ `\x02\x19l\xa9 \x07d\x00aKO]\x0f\xfcR\xf6\x04\x03\x0e\x90\x80t\xc0\x07\xf6\x83\x9a\xa1\x11\x89\x8a\x1e\x11|\xc6\x82\x02\xf0\x17D| \x1d\x1e\x17\xa0\xe8\xe5\x83<\xa8\xff2\xacU>\xedA\x9a\xa27O1"\x13<\x818\x1b\x84\x83,\xf8-S\x8c\x12\rGK\x00\x8f\xa1F\xf8St.\xe4\x9a\x05\x9b\xbc\xef\'\x1dS}HG\x0c"\x06\x12C\x89\xc1D\x1b\\\x1f\xf7\xc1\xbd\xf0\x08\xf8\xf4\x83\xcd\x11w\xc7=\x86x}\xb3\'<!\xb4\x11\x1e\x12\xae\x13:\x08\xb7\xa7\t\x0b%?0g\x82\xf1\xa0\x03r\x0c\x1e\xcc.\xf5\xfb\xecpK\xe8\xd5\x05\x0f\xc0\xbd\xa1\x7f\xe8\x1bg\xe0\xfa\xc0\x1ew\x86\x91\xfcq_\x18\xdb\x05j\xbf\xe7*\x1b\xce\xf8[-\x07}\x91\x1d\xc8(y\x04\xd9\x8fl\xfd#\x035[5\x97a/\xf2J}_\x0b%\xaf\xd4\xe1j\xb1\x86{~\xcc\x83\xf5]\xfdx\xf0\x1d\xfe\xa3%\xb6\x04;\x84\x9d\xc7Na\x17\xb1F\xac\x0e0\xb1\x13X=\xd6\x8c\x1d\x93\xe3\xe1\xb9\xf1X17\x86\xa2\xc5(\xf8dB?\xc2\x9f\xe2q\x06c\xca\xab&u\xa8v\xe8v\xf8<\xd8\x07r\xf9\xf9\xb9\xf2\xc5\xc2\xca\x11\xcf\x94\x08\xd3\x05\xb9L\x7f\xb8[\xf3\x99l\x11w\xf4(\xa6\xa3\x83\xa3\x03\x00\xf2\xbd_\xb9\xb5\xbca(\xf6t\x84q\xe9\x9bn!\x05\x00o\xd1\xc0\xc0@\xe37]\xf8\'\x00\x0e\x9b\x00@\xe9\xf8\xa6\xb3j\x87\xcbY\x0c\xc0\x85U\\\x99$O\xa9\xc3\xe5\x0f\x02\xa0\x00u\xb8R\xf4\x80\x11\xdc\xbb\xacaF\x8e\xc0\x15x\x01?\x10\x04\xc2@\x14\x88\x03I`*\xac\xb3\x00\xceS\t\x98\x01f\x83\x05\xa0\x08\x94\x80\x95`-\xd8\x00\xb6\x80\xed`7\xd8\x07\x0e\x82:\xd0\x08N\x81s\xe02h\x05\xd7\xc1]8W\xba\xc0\x0b\xd0\x0b\xde\x81~\x04AH\x08\r\xa1#z\x881b\x81\xd8!\x8e\x88;\xe2\x83\x04!\x11H\x0c\x92\x84\xa4 \xe9\x88\x08\x91!\xb3\x91\x85H\tR\x8al@\xb6!U\xc8\xef\xc8Q\xe4\x14r\x11iCn#\x9dH7\xf2\x1a\xf9\x84b(\x15\xd5F\rQKt\x0c\xea\x8e\xfa\xa3\xe1h\x1c:\x05MG\xa7\xa3\x05\xe8"t9Z\x8eV\xa2{\xd1Z\xf4\x14z\x19\xbd\x8ev\xa0/\xd0>\x0c`\xaa\x18\x033\xc1\xec1w\x8c\x85Ea\xc9X\x1a&\xc1\xe6b\xc5X\x19V\x89\xd5`\r\xf0O_\xc5:\xb0\x1e\xec#N\xc4\xe98\x13\xb7\x87\xf35\x14\x8f\xc7\xb9\xf8t|.\xbe\x0c\xdf\x80\xef\xc6k\xf13\xf8U\xbc\x13\xef\xc5\xbf\x12h\x04\x03\x82\x1d\xc1\x93\xc0&L$\xa4\x13f\x10\x8a\x08e\x84\x9d\x84#\x84\xb3p\xedt\x11\xde\x11\x89D\x06\xd1\x8a\xe8\x06\xd7^\x121\x838\x8b\xb8\x8c\xb8\x89\xb8\x9fx\x92\xd8F|D\xec#\x91Hz$;\x927)\x8a\xc4!\xe5\x92\x8aH\xebI{I\'H\xed\xa4.\xd2\x07\x15U\x15c\x15G\x95`\x95d\x15\x91J\xa1J\x99\xca\x1e\x95\xe3*\xed*OU\xfa\xc9\x1ad\x0b\xb2\'9\x8a\xcc#\xcf$\xaf \xef 7\x90\xaf\x90\xbb\xc8\xfd\x14M\x8a\x15\xc5\x9b\x12G\xc9\xa0,\xa0\x94Sj(g)\xf7(oTUUMU=T\'\xa8\nU\xe7\xab\x96\xab\x1eP\xbd\xa0\xda\xa9\xfa\x91\xaaE\xb5\xa5\xb2\xa8\x93\xa92\xear\xea.\xeaI\xeam\xea\x1b\x1a\x8dfI\xf3\xa3%\xd3ri\xcbiU\xb4\xd3\xb4\x07\xb4\x0fjt\xb5\xd1jl5\x9e\xda<\xb5\n\xb5Z\xb5v\xb5\x97\xeadu\x0bu\x7f\xf5\xa9\xea\x05\xeae\xea\x87\xd4\xaf\xa8\xf7h\x905,5X\x1a\x1c\x8d\xb9\x1a\x15\x1aG5nj\xf4i\xd25\xc7jFifk.\xd3\xdc\xa3yQ\xf3\x99\x16I\xcbR+H\x8b\xa7\xb5Hk\xbb\xd6i\xadGt\x8cnFg\xd1\xb9\xf4\x85\xf4\x1d\xf4\xb3\xf4.m\xa2\xb6\x956[;C\xbbD{\x9fv\x8bv\xaf\x8e\x96\x8e\xb3N\x82N\xbeN\x85\xce1\x9d\x0e\x06\xc6\xb0d\xb0\x19Y\x8c\x15\x8c\x83\x8c\x1b\x8cO#\x0cG\xf8\x8f\xe0\x8fX:\xa2fD\xfb\x88\xf7\xba#u\xfdt\xf9\xba\xc5\xba\xfbu\xaf\xeb~\xd2c\xea\x05\xe9e\xea\xad\xd2\xab\xd3\xbb\xaf\x8f\xeb\xdb\xeaO\xd0\x9f\xa1\xbfY\xff\xac~\xcfH\xed\x91^#\xb9#\x8bG\x1e\x1cy\xc7\x005\xb05\x881\x98e\xb0\xdd\xa0\xd9\xa0\xcf\xd0\xc80\xc4Pl\xb8\xde\xf0\xb4a\x8f\x11\xc3\xc8\xcf(\xc3h\x8d\xd1q\xa3nc\xba\xb1\x8f\xb1\xd0x\x8d\xf1\t\xe3\xe7L\x1d\xa6?3\x8bY\xce<\xc3\xec510\t5\x91\x99l3i1\xe97\xb52\x8d7-4\xddoz\xdf\x8cb\xe6n\x96f\xb6\xc6\xac\xc9\xac\xd7\xdc\xd8|\xbc\xf9l\xf3j\xf3;\x16d\x0bw\x0b\x81\xc5:\x8b\xf3\x16\xef-\xad,\x13-\x17[\xd6Y>\xb3\xd2\xb5b[\x15XU[\xdd\xb3\xa6Y\xfbZO\xb7\xae\xb4\xbefC\xb4q\xb7\xc9\xb4\xd9d\xd3j\x8b\xda\xba\xd8\nl+l\xaf\xd8\xa1v\xaevB\xbbMvm\xa3\x08\xa3<F\x89FU\x8e\xbaiO\xb5\xf7\xb7\xcf\xb3\xaf\xb6\xef\x1c\xcd\x18\x1d1\xbapt\xdd\xe8\x97c\xcc\xc7$\x8fY5\xe6\xfc\x98\xaf\x0e.\x0eY\x0e;\x1c\xee\x8e\xd5\x1a\x1b6\xb6pl\xc3\xd8\xd7\x8e\xb6\x8e\\\xc7\n\xc7kN4\xa7`\xa7yN\xf5N\xaf\x9c\xed\x9c\xf9\xce\x9b\x9do\xb9\xd0]\xc6\xbb,vir\xf9\xe2\xea\xe6*q\xadq\xedv3wKq\xdb\xe8v\xd3]\xdb=\xda}\x99\xfb\x05\x0f\x82G\x80\xc7<\x8fF\x8f\x8f\x9e\xae\x9e\xb9\x9e\x07=\xff\xf6\xb2\xf7\xca\xf4\xda\xe3\xf5l\x9c\xd58\xfe\xb8\x1d\xe3\x1ey\x9bzs\xbc\xb7yw\xf80}R|\xb6\xfat\xf8\x9a\xf8r|+}\x1f\xfa\x99\xf9\xf1\xfcv\xfa=\xf5\xb7\xf1\xcf\xf0\xdf\xeb\xff2\xc0!@\x12p$\xe0=\xcb\x935\x87u2\x10\x0b\x0c\t,\x0el\t\xd2\n\x8a\x0f\xda\x10\xf4 \xd848=\xb8:\xb87\xc4%dV\xc8\xc9PBhx\xe8\xaa\xd0\x9blC6\x97]\xc5\xee\rs\x0b\x9b\x13v&\x9c\x1a\x1e\x1b\xbe!\xfca\x84m\x84$\xa2a<:>l\xfc\xea\xf1\xf7"-"E\x91uQ \x8a\x1d\xb5:\xea~\xb4U\xf4\xf4\xe8?&\x10\'DO\xa8\x98\xf0$fl\xcc\xec\x98\xf3\xb1\xf4\xd8i\xb1{b\xdf\xc5\x05\xc4\xad\x88\xbb\x1bo\x1d/\x8boJPO\x98\x9cP\x95\xf0>10\xb14\xb1c\xe2\x98\x89s&^N\xd2O\x12&\xd5\'\x93\x92\x13\x92w&\xf7M\n\x9a\xb4vR\xd7d\x97\xc9E\x93oL\xb1\x9a\x92?\xe5\xe2T\xfd\xa9YS\x8fMS\x9f\xc6\x99v(\x85\x90\x92\x98\xb2\'\xe53\'\x8aS\xc9\xe9Ke\xa7nL\xed\xe5\xb2\xb8\xeb\xb8/x~\xbc5\xbcn\xbe7\xbf\x94\xff4\xcd;\xad4\xedY\xbaw\xfa\xea\xf4n\x81\xaf\xa0L\xd0#d\t7\x08_e\x84fl\xc9x\x9f\x19\x95\xb9+s +1k\x7f\xb6JvJ\xf6Q\x91\x96(St&\xc7(\'?\xa7Ml\'.\x12wL\xf7\x9c\xbevz\xaf$\\\xb2S\x8aH\xa7H\xebs\xb5\xe1!\xbbYf-\xfbE\xd6\x99\xe7\x93W\x91\xf7aF\xc2\x8cC\xf9\x9a\xf9\xa2\xfc\xe6\x99\xb63\x97\xce|Z\x10\\\xf0\xdb,|\x16wV\xd3l\x93\xd9\x0bfw\xce\xf1\x9f\xb3m.27un\xd3<\xb3y\x8b\xe6u\xcd\x0f\x99\xbf{\x01eA\xe6\x82?\x0b\x1d\nK\x0b\xdf.L\\\xd8\xb0\xc8p\xd1\xfcE\x8f~\t\xf9\xa5\xbaH\xadHRts\xb1\xd7\xe2-K\xf0%\xc2%-K\x9d\x96\xae_\xfa\xb5\x98W|\xa9\xc4\xa1\xa4\xac\xe4\xf32\xee\xb2K\xbf\x8e\xfd\xb5\xfc\xd7\x81\xe5i\xcb[V\xb8\xae\xd8\xbc\x92\xb8R\xb4\xf2\xc6*\xdfU\xbbK5K\x0bJ\x1f\xad\x1e\xbf\xbav\rsM\xf1\x9a\xb7k\xa7\xad\xbdX\xe6\\\xb6e\x1de\x9dl]GyDy\xfdz\xf3\xf5+\xd7\x7f\xde \xd8p\xbd"\xa0b\xffF\x83\x8dK7\xbe\xdf\xc4\xdb\xd4\xbe\xd9os\xcd\x16\xc3-%[>m\x15n\xbd\xb5-d[m\xa5ee\xd9v\xe2\xf6\xbc\xedOv$\xec8\xff\x9b\xfboU;\xf5w\x96\xec\xfc\xb2K\xb4\xabcw\xcc\xee3UnUU{\x0c\xf6\xac\xa8F\xabe\xd5\xdd{\'\xefm\xdd\x17\xb8\xaf\xbe\xc6\xbef\xdb~\xc6\xfe\x92\x03\xe0\x80\xec\xc0\xf3\xdfS~\xbfq0\xfc`\xd3!\xf7C5\x87-\x0eo<B?R\\\x8b\xd4\xce\xac\xed\xad\x13\xd4u\xd4\'\xd5\xb7\x1d\r;\xda\xd4\xe0\xd5p\xe4\x8f\xd1\x7f\xecj4i\xac8\xa6sl\xc5q\xca\xf1E\xc7\x07N\x14\x9c\xe8;)>\xd9s*\xfd\xd4\xa3\xa6iMwOO<}\xed\xcc\x843-g\xc3\xcf^8\x17|\xee\xf4y\xff\xf3\'.x_h\xbc\xe8y\xf1\xe8%\xf7Ku\x97]/\xd76\xbb4\x1f\xf9\xd3\xe5\xcf#-\xae-\xb5W\xdc\xae\xd4\xb7z\xb46\xb4\x8dk;\xde\xee\xdb~\xeaj\xe0\xd5s\xd7\xd8\xd7._\x8f\xbc\xdev#\xfe\xc6\xad\x9b\x93ov\xdc\xe2\xddzv;\xeb\xf6\xab;yw\xfa\xef\xce\xbfG\xb8W|_\xe3~\xd9\x03\x83\x07\x95\xff\xb2\xf9\xd7\xfe\x0e\xd7\x8ec\x9d\x81\x9d\xcd\x0fc\x1f\xde}\xc4}\xf4\xe2\xb1\xf4\xf1\xe7\xaeEOhO\xca\x9e\x1a?\xadz\xe6\xf8\xac\xb1;\xb8\xbb\xf5\xf9\xa4\xe7]/\xc4/\xfa{\x8a\xfe\xd2\xfck\xe3K\xeb\x97\x87\xff\xf6\xfb\xbb\xb9wbo\xd7+\xc9\xab\x81\xd7\xcb\xde\xe8\xbd\xd9\xf5\xd6\xf9mS_t\xdf\x83w\xd9\xef\xfa\xdf\x17\x7f\xd0\xfb\xb0\xfb\xa3\xfb\xc7\xf3\x9f\x12?=\xed\x9f\xf1\x99\xf4\xb9\xfc\x8b\xcd\x97\x86\xaf\xe1_\xef\rd\x0f\x0c\x889\x12\x8e\xe2(\x80\xc1\x86\xa6\xa5\x01\xf0z\x17\x00\xb4$\x00\xe8\xad\xf0\xfc0Iy7S\x08\xa2\xbcO*\x10\xf8OXy\x7fS\x88+\x005\xf0%?\x86\xb3N\x02p\x006\xcb\xf9\xd07l\xf2#x\x9c\x1f@\x9d\x9c\x86\xdb\xa0H\xd3\x9c\x1c\x95\xbe\xa8\xf0\xc6B\xf800\xf0\xc6\x10\x00R\x03\x00_$\x03\x03\xfd\x9b\x06\x06\xbe\xec\x80do\x03pr\xba\xf2N(\x17\xf9\x1dt\xab\xb3\x1c\xb53\xf2\xe7\x83\x1f\xe4\xdf\xe3\x8aqsT\xed$\x9b\x00\x00\x00\tpHYs\x00\x00\x16%\x00\x00\x16%\x01IR$\xf0\x00\x00\x01\x9diTXtXML:com.adobe.xmp\x00\x00\x00\x00\x00<x:xmpmeta xmlns:x="adobe:ns:meta/" x:xmptk="XMP Core 5.4.0">\n   <rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">\n      <rdf:Description rdf:about=""\n            xmlns:exif="http://ns.adobe.com/exif/1.0/">\n         <exif:PixelXDimension>572</exif:PixelXDimension>\n         <exif:PixelYDimension>234</exif:PixelYDimension>\n      </rdf:Description>\n   </rdf:RDF>\n</x:xmpmeta>\n\xdc\x92\xe8)\x00\x00\x00\x1ciDOT\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00u\x00\x00\x00(\x00\x00\x00u\x00\x00\x00u\x00\x00\x12UC\xe4\xa9g\x00\x00\x12!IDATx\x01\xec\x9dO\x88]E\x16\xc6\x8f\x8b(\x82\xddq\x0cj\x10i\x90\xa1u\x06\\\xb8t\xadY\x19z\xb2\x88\xed,l!\x90d\xd7\xd8\x82YE\xccr\x92e\xc8&.\x0c\x18\xb3\xcab\x84L\x90HH3N/\\$\xbd\xb2\rd#\x98\xa0\x9d\x85\xc4EK\x04;63\xaf\xa7\xff\xd0T\xbf[\xb7\xaa\xce\xbd\xf5\xea\xdc\xfb\x0bH\xfa\xbd\xaaS\xef\xbc\xdf\xf7U\xd5g:\xe9\xf7\xd8_\xfe\xfa\xe7\xff\n\xbf \x00\x01\x08@\x00\x02\x10\x80@\x87\t<F\xe0\xe9\xb0\xba\xbc5\x08@\x00\x02\x10\x80\x00\x04\xfeO\x80\xc0\x83\x11 \x00\x01\x08@\x00\x02\x10\xe8<\x01\x02O\xe7%\xe6\rB\x00\x02\x10\x80\x00\x04 @\xe0\xc1\x03\x10\x80\x00\x04 \x00\x01\x08t\x9e\x00\x81\xa7\xf3\x12\xf3\x06!\x00\x01\x08@\x00\x02\x10 \xf0\xe0\x01\x08@\x00\x02\x10\x80\x00\x04:O\x80\xc0\xd3y\x89y\x83\x10\x80\x00\x04 \x00\x01\x08\x10x\xf0\x00\x04 \x00\x01\x08@\x00\x02\x9d\'@\xe0\xe9\xbc\xc4\xbcA\x08@\x00\x02\x10\x80\x00\x04\x08<x\x00\x02\x10\x80\x00\x04 \x00\x81\xce\x13 \xf0t^b\xde \x04 \x00\x01\x08@\x00\x02\x04\x1e<\x00\x01\x08@\x00\x02\x10\x80@\xe7\t\x10x:/1o\x10\x02\x10\x80\x00\x04 \x00\x01\x02\x0f\x1e\x80\x00\x04 \x00\x01\x08@\xa0\xf3\x04\x08<\x9d\x97\x987\x08\x01\x08@\x00\x02\x10\x80\x00\x81\x07\x0f@\x00\x02\x10\x80\x00\x04 \xd0y\x02\x04\x9e\xceK\xcc\x1b\x84\x00\x04 \x00\x01\x08@\x80\xc0\x83\x07 \x00\x01\x08@\x00\x02\x10\xe8<\x01\x02O\xe7%\xe6\rB\x00\x02\x10\x80\x00\x04 @\xe0\xc1\x03\x10\x80\x00\x04 \x00\x01\x08t\x9e\x00\x81\xa7\xf3\x12\xf3\x06!\x00\x01\x08@\x00\x02\x10 \xf0\xe0\x01\x08@\x00\x02\x10\x80\x00\x04:O\x80\xc0\xd3y\x89y\x83\x10\x80\x00\x04 \x00\x01\x08d\x0b<\x13\x13\x13\xf2\xf6\xe1\xc3\xc9\xc4\xc7\xc7\xc7errR\x96\x96\x96duu5y\x9dO/\\\x90\x95\x95\x95\xe4z\n\xd3\x08\x8cZ\x7f\xad\x7f\xfa^\xbf\xa5z\xea\xfeA\x7f\xdd\xf95j\xff\xa1\xbfm\xfd\xac\xfbg\xcb\x7f\xda\xdf\xb3\x05\x9e\xd7_\x7f]>9\x7f^\xdb\xaf\xba\xfe\xad\x83\x07eyyY\xbd\x0e\x0b\xc4\x11(E\xff\xb8\xae\x99\xed\x12H\xdd?\xe8\xef\x92\xb4\xf9\x18\xfdm\xeaVJ\xd7\xa9\xfei\xaa\x7f\x02OS$Y\xc7K\x80\x0b\xcf\x8b\xc7\xcc`\xea\x81\x85\xfef$\xf66\x8a\xfe^<\x0c\xd6\x10H\xf5O\xcd\xb2\xc1\xc3\x04\x9e`TL\xd4\x10\xe0\xc2\xd3\xd0+\xa76\xf5\xc0B\xffr4\xd4t\x82\xfe\x1az\xd4\xa6\xfa\xa7)r\x04\x9e\xa6H\xb2\x8e\x97\x00\x17\x9e\x17\x8f\x99\xc1\xd4\x03\x0b\xfd\xcdH\xecm\x14\xfd\xbdx\x18\xac!\x90\xea\x9f\x9ae\x83\x87\t<\xc1\xa8\x98\xa8!\xc0\x85\xa7\xa1WNm\xea\x81\x85\xfe\xe5h\xa8\xe9\x04\xfd5\xf4\xa8M\xf5OS\xe4\x08<M\x91d\x1d/\x01.</\x1e3\x83\xa9\x07\x16\xfa\x9b\x91\xd8\xdb(\xfa{\xf10XC \xd5?5\xcb\x06\x0f\x13x\x82Q1QC\x80\x0bOC\xaf\x9c\xda\xd4\x03\x0b\xfd\xcb\xd1P\xd3\t\xfak\xe8Q\x9b\xea\x9f\xa6\xc8\x11x\x9a"\xc9:^\x02\\x^<f\x06S\x0f,\xf47#\xb1\xb7Q\xf4\xf7\xe2a\xb0\x86@\xaa\x7fj\x96\r\x1e&\xf0\x04\xa3b\xa2\x86\x00\x17\x9e\x86^9\xb5\xa9\x07\x16\xfa\x97\xa3\xa1\xa6\x13\xf4\xd7\xd0\xa36\xd5?M\x91\xeb]\xe0\xf9\xfc\xd2%\xf95\xe0\'-\xdf\xbdwO\xae_\xbf\xde\x14\xe7\xde\xaf\xc3\x85\xd7\r\x0b\xa4\xee\x1f\xf4G\xff\x12~\xf0l7T\xb0\xfb.R\xcf\x8f\xa6\xdeq\xef\x02O(\xb8\x85\x85\x05y\x7fn.t:\xf3j\x08p\xe1\xd5\x00\xea\xd8\xb0\xbb\x7f\xd0\xbfc\x02\xd7\xbc\x1d\xf4\xaf\x01\xc4\xb0\x97\x80\xeb\x1f\xef\xe4\x88\xc1\xde\x05\x9e\xfb\xf7\xef\xcb\xda\xdaZ%\xa2\xf5\xcf\x1cY\xff\xaf-\xe0\x95/\xdc\xf1\x01.\xbcn\x08\x9c\xba\x7f\xd0\x1f\xfd\xf9\x13\x9enx@\xf3.R\xcf\x0f\xcdk\xee\xac\xed]\xe0\xa9\xfb\x1e\xe2\xb1\xa3Gevv\x96\xc0\xb3\xd3%\r|\xcd\x85\xd7\x00\xc4\x02\x96H\xdd?\xe8_\x80x\r\xb4\x80\xfe\r@\xec\xf1\x12\xa9\xfei\n\x19\x81\xc7!I\xe0q\x804\xf4\x90\x0b\xaf!\x90#^&\xf5\xc0B\xff\x11\x0b\xd7\xd0\xcb\xa3\x7fC {\xbaL\xaa\x7f\x9a\xc2\xd5\xbb\xc0s\xe7\xce\x1dy\xf4\xe8\xd1.~\xe7\xce\x9d\x93[\x8b\x8bB\xe0\xd9\x85\xa6\x91\'\xb8\xf0\x1a\xc18\xf2ER\xf7\x0f\xfa\x8f\\\xbaF\x1a@\xffF0\xf6v\x91T\xff4\x05\xacw\x81\xa7\n\xdc\x87\'N\xc8\xfc\xfc<\x81\xa7\n\x90\xf2y.<%\xc0\xc2\xcb\xeb\xf6\x0f\xfa\x17.\xa0\xb2=\xf4W\x02\xecyy\x9d\x7f\x9a\xc2\xd3\xbb\xc0s\xe5\xca\x15y\xf8\xf0\xe16\xbf\xa9\xa9)\x19\x1b\x1b\x93\\\xc0\xb7_\xb8g_p\xe1uC\xf0\xd4\xfd\x83\xfe\xe8\xcf_Z\xee\x86\x074\xef"\xf5\xfc\xd0\xbc\xe6\xce\xda\xde\x05\x1e\xf7{\x88\xff\x1a\x04\xa0\x89\x89\t\x02\xcfNW\xb4\xf05\x17^\x0bPG\xb0d\xea\xfeA\xff\x11\x88\xd5\xc2K\xa2\x7f\x0bP{\xb4d\xaa\x7f\x9aBD\xe0!\xf04\xe5%\xef:\\x^<f\x06S\x0f,\xf47#\xb1\xb7Q\xf4\xf7\xe2a\xb0\x86@\xaa\x7fj\x96\r\x1e&\xf0\x10x\x82\xcd\xa2\x99\xc8\x85\xa7\xa1WNm\xea\x81\x85\xfe\xe5h\xa8\xe9\x04\xfd5\xf4\xa8M\xf5OS\xe4\x08<\x04\x9e\xa6\xbc\xe4]\x87\x0b\xcf\x8b\xc7\xcc`\xea\x81\x85\xfef$\xf66\x8a\xfe^<\x0c\xd6\x10H\xf5O\xcd\xb2\xc1\xc3\x04\x1e\x02O\xb0Y4\x13\xb9\xf04\xf4\xca\xa9M=\xb0\xd0\xbf\x1c\r5\x9d\xa0\xbf\x86\x1e\xb5\xa9\xfei\x8a\x1c\x81\x87\xc0\xd3\x94\x97\xbc\xebp\xe1y\xf1\x98\x19L=\xb0\xd0\xdf\x8c\xc4\xdeF\xd1\xdf\x8b\x87\xc1\x1a\x02\xa9\xfe\xa9Y6x\x98\xc0C\xe0\t6\x8bf"\x17\x9e\x86^9\xb5\xa9\x07\x16\xfa\x97\xa3\xa1\xa6\x13\xf4\xd7\xd0\xa36\xd5?M\x91#\xf0\x10x\x9a\xf2\x92w\x1d.</\x1e3\x83\xa9\x07\x16\xfa\x9b\x91\xd8\xdb(\xfa{\xf10XC \xd5?5\xcb\x06\x0f\x13x\x08<\xc1f\xd1L\xe4\xc2\xd3\xd0+\xa76\xf5\xc0B\xffr4\xd4t\x82\xfe\x1az\xd4\xa6\xfa\xa7)r\x04\x1e\x02OS^\xf2\xae\xc3\x85\xe7\xc5cf0\xf5\xc0B\x7f3\x12{\x1bE\x7f/\x1e\x06k\x08\xa4\xfa\xa7f\xd9\xe0\xe1\xde\x07\x9e\xaf\xae]\x93\xfd\xfb\xf7\xcb\xc7\xa7N\xc9\xd5\xabW\xe5\x83\xb999r\xe4\x88,\xae\x7f\x90\xe8\xf1\xe3\xc1 \x99\xe8\'\xc0\x85\xe7\xe7ce\xd4=\xb0B\xf7\x0f\xfa[Q\xd8\xdf\'\xfa\xfb\xf90\xea\'\x90\xea\x1f\xff\xaa\xe1\xa3\xd9\x02OxKyg\xde\xbayS\xf6\xec\xd9#\x9f]\xbc(g\xcf\x9e\x95\xf5\xcf{Y?\x9c\x1f<x o\x1e8\x90\xb7\x19^-;\x01>ZD\x87\x9c\xfd\xa3\xe3g\xbdZ\xab?\xfb\xcf\xba\x03t\xfdk\xfd\x13\xfb\xea\xbd\x0f<\xf37n\xc8\xbe}\xfb\xe4\xf4\x993r\xf9\xf2e\xf9\xe8\xe4I\x99\x9e\x9e\x96\xdb\xb7o\xcb\xbb33\xb1<\x99o\x8c\x00\x07\xaeN0\xf6\x8f\x8e\x9f\xf5j\xad\xfe\xec?\xeb\x0e\xd0\xf5\xaf\xf5O\xec\xab\xf7>\xf0\xb0\xe1b-\xd3\xad\xf9\xe8\xaf\xd3\x13~:~\xd6\xab\xb5\xfak\xeb\xad\xf3\xeb{\xff\xb9\xf5\'\xf0\xf0\x97\x96{\xbd\xe7ro\xb8\xae\xc1\x86_\xd7\x14\x8d{?Z\xfd\xb5\xf5q\xdd2\xbb4\x02\xb9\xf5\'\xf0\x10xJ\xdb\x03Y\xfb\xc9\xbd\xe1\xb2\xbe\xb9\x0c/\x06\xbf\x0c\x90\x0b~\t\xad\xfe\xda\xfa\x82\xd1\xd0Z\x00\x81\xdc\xfag\x0b<\x13\x13\x13\xf2\xf6\xe1\xc3\x01\x08\x86O\x19\x1f\x1f\x97\xc9\xc9IYZZ\x92\xd5\xd5\xd5\xe1\x93\x02\x9e\xfd\xf4\xc2\x05YYY\xd9\x9e\x99\x1b\xf8\xf6\x0b\xf7\xec\x0b\xf4\xd7\tn\x9d_\xa9\xfd\xebT\xa1Z{~j\xebs)\x80\x7f\xdb!\x9d[\xffl\x81\xa7\x94\x7f\x96\xea\xfe\xb3\xb8\xdc\xc0\xdb\xb1M\xf9\xab\xa2\xbfN#\xeb\xfcJ\xed_\xa7\n\xd5\xda\xf3S[\x9fK\x01\xfc\xdb\x0e\xe9\xdc\xfa\x13x\xf8\x96V;NvV-\xf5\xc0\xc8\xbd\xe1\x1c,\xc1\x0f\xad\xf3+\xb5\xff`\x01\x988\x94\x80v\xffh\xeb\x876\xd5\xc2\x93\xf8\xb7\x05\xa8\x83%s\xebO\xe0!\xf0\xb4\xe3dg\xd5R\x0f\x8c\xdc\x1b\xce\xc1\x12\xfc\xd0:\xbfR\xfb\x0f\x16\x80\x89C\th\xf7\x8f\xb6~hS-<\x89\x7f[\x80:X2\xb7\xfe\x04\x1e\x02O;NvV-\xf5\xc0\xc8\xbd\xe1\x1c,\xc1\x0f\xad\xf3+\xb5\xff`\x01\x988\x94\x80v\xffh\xeb\x876\xd5\xc2\x93\xf8\xb7\x05\xa8\x83%s\xebO\xe0!\xf0\xb4\xe3dg\xd5R\x0f\x8c\xdc\x1b\xce\xc1\x12\xfc\xd0:\xbfR\xfb\x0f\x16\x80\x89C\th\xf7\x8f\xb6~hS-<\x89\x7f[\x80:X2\xb7\xfe\x04\x1e\x02O;NvV-\xf5\xc0\xc8\xbd\xe1\x1c,\xc1\x0f\xad\xf3+\xb5\xff`\x01\x988\x94\x80v\xffh\xeb\x876\xd5\xc2\x93\xf8\xb7\x05\xa8\x83%s\xebO\xe0!\xf0\xb4\xe3dg\xd5R\x0f\x8c\xdc\x1b\xce\xc1\x12\xfc\xd0:\xbfR\xfb\x0f\x16\x80\x89C\th\xf7\x8f\xb6~hS-<\x89\x7f[\x80:X2\xb7\xfe\x04\x1e\x02O;NvV-\xf5\xc0\xc8\xbd\xe1\x1c,\xc1\x0f\xad\xf3+\xb5\xff`\x01\x988\x94\x80v\xffh\xeb\x876\xd5\xc2\x93\xf8\xb7\x05\xa8\x83%s\xebO\xe0!\xf0\xb4\xe3dg\xd5R\x0f\x8c\xdc\x1b\xce\xc1\x12\xfc\xd0:\xbfR\xfb\x0f\x16\x80\x89C\th\xf7\x8f\xb6~hS-<\x89\x7f[\x80:X2\xb7\xfe\x04\x1e\x02O;NvV-\xf5\xc0\xc8\xbd\xe1\x1c,\xc1\x0f\xad\xf3+\xb5\xffw\xdeyG\xf6\x0e~\x8a{\xdd\xaf\xb1\xb11y\xe5\x95W\xe4\xdbo\xbfM\xfaI\xef]\xad\x9f\x99\x99\x91\xbd{\xf7\xca\x87\'N\xc8\xfc\xfc\xbc\x1c;zTfggeaaA\xde\x9f\x9b\xab\xc3Zy\xe1\xfd\xf0\xc3\x0f\xf2\xe5\x97_n\xd7\x8f\x9a\xdf\x8b/\xbe(\x87\x0e\x1d\xda\xeegT_\xb8?8\xd7\xba\x7f\xb5\xfe\x89\xd5\x81\xc0C\xe0\x89\xf5L\xd2\xfcR/<\x02O\x9c\x9c\xee\x81\x1b\xca\xaft\xfd\xe3(0\xdb%\xd0t\xe0q\xd7\xe7\xf1\x06\x81\xaa\xfdg\x9dO\xaa\x7fb\xdf7\x81\x87\xc0\x13\xeb\x99\xa4\xf9\xa5_x\xb96\\\x12\xbcA\x91u~\xa5\xf7\xff\xcb/\xbf\xc8o\xbf\xfdV)\xcf\xe3\x8f?.\xcf<\xf3\x8c\xfc\xfc\xf3\xcf\xb2\xb6\xb6V9\xafj\xa0\xeb\xf5\xff8}Z\xbe\xf9\xe6\x1b\xf5\x9f\xf0\xfc}\xf0\'n\xef\xbd\xf7\xde.\x8c\xa3\xe6\xf7\xc4\x13O\xc8\xb3\xcf>\xbb\xab\xaf\xdcOT\x05\x1e\xeb\xfeM\xf5O,\x7f\x02\x0f\x81\'\xd63I\xf3K\xbf\xf0\x08<a\xb2V\x1d\xb8u\xfc\xac\xe8\x1fF\x81YU\x04\xb4\xdf\xd2\xaaZw\xd4\xcf\xe3\xdf<\n\xc4\xfa\'\xb6+\x02\x0f\x81\'\xd63I\xf3\xad\x1c\x18mo\xb8$x\x83"\xeb\xfc\xac\xf4\x9f\xaa\x0fu\x1b\x04b\xf7\x8f\xfb-\xd1R9\xe2\xdf<\xca\xc4\xfa\'\xb6+\x02\x0f\x81\'\xd63I\xf3\xad\x1c\x18mo\xb8$x\x83"\xeb\xfc\xac\xf4\xff\xb7\xa9)\x99\x9e\x9e\xde%\xd3\x93O>)/\xbc\xf0\x82\xdc\xbd{W\xfe\xf8\xe3\x8f]\xe3uO\xf4\xa5\xfe\xb9\xe7\x9e\x93\xe7\x9f\x7f>\xfa/-\xafs]YY\xa9\xc48j~O=\xf5\x94\xbc\xf4\xd2K\x95\xfd\xe5\x1a\xa8\xfb\x13V\xeb\xfe\x8d\xf5O,w\x02\x0f\x81\'\xd63I\xf3\xad\\x\x04\x1e\xbf\xbcu\x07n\x15?k\xfa\xfb)0ZG \xf6_i\xd5\xad\xc7\xf8\x06\x81\xd0\xfdg\x9dW\xa8\x7fb\xdf\'\x81\x87\xc0\x13\xeb\x99\xa4\xf9\xd6.\xbc\xb66\\\x12\xbcA\x91u~\xd6\xfa\xffiyY\xfe\xf3\xf5\xd7\xdbr\xad\xff\xb3\xe8\x97_~Y\x96\xbe\xfbNV\x7f\xff}\xfb\xf9\xd0/\xfaV\xff\xfd\xf7\xdf\xcb?\xbf\xf8\xa2\x16\xcf\xf1\xe3\xc7\xe5OO?];o\xd4\xfc\xf6\xef\xdf/o\xbc\xf1Fm\x9fmO\x08\r<\xd6\xfd\x1b\xea\x9fX\xde\x04\x1e\x02O\xacg\x92\xe6[\xbb\xf0\x08<\xc3e\x0e=p]~\xe8?\x9c\'\xcf\xda \x80\x7fm\xe8T\xd7%\x81\x87\xc0S\xe7\x91F\xc690t\x18\xad\xf3\xb3\xde\xbfN=\xaa\xad\x13\xc0\xbf\xd6\x15\xdc\xe8\x9f\xc0C\xe0\xc9\xe2d\x0e\x0c\x1df\xeb\xfc\xac\xf7\xafS\x8fj\xeb\x04\xf0\xafu\x057\xfa\'\xf0\x10x\xb28\x99\x03C\x87\xd9:?\xeb\xfd\xeb\xd4\xa3\xda:\x01\xfck]\xc1\x8d\xfe\t<\x04\x9e,N\xe6\xc0\xd0a\xb6\xce\xcfz\xff:\xf5\xa8\xb6N\x00\xffZWp\xa3\x7f\x02\x0f\x81\'\x8b\x9390t\x98\xad\xf3\xb3\xde\xbfN=\xaa\xad\x13\xc0\xbf\xd6\x15\xdc\xe8\x9f\xc0C\xe0\xc9\xe2d\x0e\x0c\x1df\xeb\xfc\xac\xf7\xafS\x8fj\xeb\x04\xf0\xafu\x057\xfa\'\xf0\x10x\xb28\x99\x03C\x87\xd9:?\xeb\xfd\xeb\xd4\xa3\xda:\x01\xfck]\xc1\x8d\xfe\t<\x04\x9e,N\xe6\xc0\xd0a\xb6\xce\xcfz\xff:\xf5\xa8\xb6N\x00\xffZWp\xa3\x7f\x02\x0f\x81\'\x8b\x9390t\x98\xad\xf3\xb3\xde\xbfN=\xaa\xad\x13\xc0\xbf\xd6\x15\xdc\xe8\xbf\xf7\x81\xe7\xabk\xd7d\xfd\xc7\x86\x7f|\xea\x94\\\xbdzU>\x98\x9b\x93#G\x8e\xc8\xe2\xe2\xa2\x1c\x1b\xfc\xd8s~5C\xa0\xd4\x03\xc3\x8a\xfe\xd6\xf9\x95\xda\xbf\xfbi\xddU\x9f\x05\xd6\xcc.`\x15\xab\x04J\xf5\xaf\x95\xf3\xab\x14\xdd\xb3\x05\x9eR\xde\xb0\xdb\xc7\xad\x9b7e\xcf\x9e=\xf2\xd9\xc5\x8br\xf6\xecY\xf9\xe4\xfc\xf9\xff\x7fn\xd1\x83\x07\x0f\xe4\xcd\x03\x07\xdc\xe9<\xee\x18\x01\xf4\xd7\tj\x9d\x1f\x81G\xa7?\xd5\xa3%`}\xff\xe5\xa6\xd7\xfb\xc03\x7f\xe3\x86\xec\xdb\xb7ON\x9f9#\x97/_\x96\x8fN\x9e\x94\xe9\xe9i\xb9}\xfb\xb6\xbc;3\x93[\x0f^/3\x01\xf4\xd7\x01\xb7\xce\xef\xd0\xa1C\xb2\xfe\xc1\x94\xeb\x9f\xfdu\xef\xde=y\xf5\xd5W\xe5\xb5\xd7^\x93\x9f~\xfcQ\xfe\xbd\xe3\xc3Cu\x94\xa8\x86@;\x04\xac\xef\xbfv\xa8T\xaf\xda\xfb\xc0\xc3\xff\xe1U\x9b\xa3\x0f#\xe8\xafS\x19~:~TC@C\x80\xfd\x17G\x8f\xc0\xc3_Z\x8esL\xc7fs`\xe8\x04\x85\x9f\x8e\x1f\xd5\x10\xd0\x10`\xff\xc5\xd1#\xf0\x10x\xe2\x1c\xd3\xb1\xd9\x1c\x18:A\xe1\xa7\xe3G5\x044\x04\xd8\x7fq\xf4\xb2\x05\x9e\x89\x89\ty\xfb\xf0\xe1\xb8\xeev\xcc\x1e\x1f\x1f\x97\xc9\xc9IYZZ\x92\xd5\xd5\xd5\x1d#q_~z\xe1\x82\xac\xac\xacl\x17a\x98m\x14\xad~\x81\xfe:\xbc\xd6\xf9\x8d\xba\x7f\xed\xf9\xd1\xf7\xfa-\xf7\xba\xe7\xe7\xd6\xf3]\xff}\xd4\xfe\xdd\xe2\xeb\xf2\xe7\xfe\xda"\x13\xf6{\xb6\xc0S\xea?\xeb\xc30aF\xd1\xceB\x7f\x1dA\xeb\xfcJ\xe9_\xa7\x02\xd5o\x1d<(\xcb\xcb\xcb\xbd\x03Q\x8a\x7f]\xfe\xdc_qV$\xf0\xf0-\xad8\xc7$\xce\xe6\xc0H\x04\xb7Yf\x9d_)\xfd\xebT\xa0\xda\xbdp\xfbB\xa4\x14\xff\xba\xfc\t<q\x0e$\xf0\x10x\xe2\x1c\x938\x9b\x03#\x11\xdcf\x99u~\xa5\xf4\xafS\x81j\xf7\xc2\xed\x0b\x91R\xfc\xeb\xf2\'\xf0\xc49\x90\xc0C\xe0\x89sL\xe2l\x0e\x8cDp\x9be\xd6\xf9\x95\xd2\xbfN\x05\xaa\xdd\x0b\xb7/DJ\xf1\xaf\xcb\x9f\xc0\x13\xe7@\x02\x0f\x81\'\xce1\x89\xb390\x12\xc1m\x96Y\xe7WJ\xff:\x15\xa8v/\xdc\xbe\x10)\xc5\xbf.\x7f\x02O\x9c\x03\t<\x04\x9e8\xc7$\xce\xe6\xc0H\x04\xb7Yf\x9d_)\xfd\xebT\xa0\xda\xbdp\xfbB\xa4\x14\xff\xba\xfc\t<q\x0e$\xf0\x10x\xe2\x1c\x938\x9b\x03#\x11\xdcf\x99u~\xa5\xf4\xafS\x81j\xf7\xc2\xed\x0b\x91R\xfc\xeb\xf2\'\xf0\xc49\x90\xc0C\xe0\x89sL\xe2l\x0e\x8cDp\x9be\xd6\xf9\x95\xd2\xbfN\x05\xaa\xdd\x0b\xb7/DJ\xf1\xaf\xcb\x9f\xc0\x13\xe7@\x02\x0f\x81\'\xce1\x89\xb390\x12\xc1m\x96Y\xe7WJ\xff:\x15\xa8v/\xdc\xbe\x10)\xc5\xbf.\x7f\x02O\x9c\x03\t<\x04\x9e8\xc7$\xce\xe6\xc0H\x04\xb7Yf\x9d_)\xfd\xebT\xa0\xfa\xf3K\x97\xe4\xd7\x1d?\xa9\xbe\x8a\xc8\xdd\xc1\'\xcf_\xbf~\xbdj\xd8\xdc\xf3\xa5\xf8\x97\xc0\xa3\xb3\x0e\x81\x87\xc0\xa3sP`5\x07F \xa8\x8ai\xd6\xf9\x95\xd2\x7f\x05^\x9en\x98\xc0\xc2\xc2\x82\xbc?7\xd7\xf0\xaa\xa3[\xae\x14\xff\x12xt\x1e \xf0\x10xt\x0e\n\xac\xe6\xc0\x08\x04U1\xcd:\xbfR\xfa\xaf\xc0\xcb\xd3\x81\x04\xee\xdf\xbf/kkk\x95\xb3\xd7?sl\xfd?\x02O%"\xd5\x00\x81G\x85O\x08<\x04\x1e\x9d\x83\x02\xabK\xb9\xf0\xac\x1e\x18\xd6\xf9\x95\xd2\x7f\xa0]\x99VA\xc0\xdd?\xee\xb4cG\x8f\xca\xec\xec,\x81\xc7\x05\xd3\xd0c\x97?\x7f\x87\'\x0e,\x81\x87\xc0\x13\xe7\x98\xc4\xd9\xa5\\xV\x0f\x0c\xeb\xfcJ\xe9?\xd1\xbe\x94m\x12p\xf7\x8f\x0b\x86\xc0\xe3\x12i\xf6\xb1\xcb\x9f\xc0\x13\xc7\x97\xc0C\xe0\x89sL\xe2\xecR.<\xab\x07\x86u~\xa5\xf4\x9fh_\xca6\t\xdc\xb9sG\x1e=z\xb4\x8b\xc7\xb9s\xe7\xe4\xd6\xe2\xa2\x10xv\xa1i\xf4\t\xab\xe7W\xa3\x10\x14\x8b\x11x\x08<\n\xfb\x84\x97\x96r\xe1Y=0\xac\xf3+\xa5\xffp\xc723\x86\xc0\x87\'N\xc8\xfc\xfc<\x81\'\x06Z\xc2\\\xab\xe7W\xc2[m\xa5\x84\xc0C\xe0i\xc5X\xee\xa2\xa5\\xV\x0f\x0c\xeb\xfcJ\xe9\xdf\xf5%\x8f\xe3\x08\\\x19\x9c\x97\x0f\x1f>\xdc.\x9a\x9a\x9a\x92\xb1\xb11!\xf0l#i\xf5\x0b\xab\xe7W\xabP"\x16\'\xf0\x10x"\xec\x92>\xb5\x94\x0b\xcf\xea\x81a\x9d_)\xfd\xa7;\x98\xcau\x02V\xf7\x8fV\xbdR\xfc\xdbW\xfeZ\xfd\xb6\xea\t<\x04\x9e-/\xb4\xfa;\x07\x86\x0e\xafu~\xa5\xf4\xafS\x81\xea\xbe^\xb8\xa5\xf8\xb7\xaf\xfc\x9b\xday\x04\x1e\x02OS^\xf2\xae\xc3\x81\xe1\xc5S;h\x9d_)\xfd\xd7\x82f\x82\x97@_/\xdcR\xfc\xdbW\xfe^SF\x0c\x12x\x08<\x11vI\x9f\xca\x81\x91\xcen\xbd\xd2:\xbfR\xfa\xd7\xa9@u_/\xdcR\xfc\xdbW\xfeM\xed<\x02\x0f\x81\xa7)/y\xd7\xe1\xc0\xf0\xe2\xa9\x1d\xb4\xce\xaf\x94\xfekA3\xc1K\xa0\xaf\x17n)\xfe\xed+\x7f\xaf)#\x06\t<\x04\x9e\x08\xbb\xa4O\xe5\xc0Hg\xb7^i\x9d_)\xfd\xebT\xa0\xba\xaf\x17n)\xfe\xed+\xff\xa6v\x1e\x81\x87\xc0\xd3\x94\x97\xbc\xebp`x\xf1\xd4\x0eZ\xe7WJ\xff\xb5\xa0\x99\xe0%\xd0\xd7\x0b\xb7\x14\xff\xf6\x95\xbf\xd7\x94\x11\x83\xff\x03\x00\x00\xff\xff\xe1\xcfLc\x00\x00\x11\xa7IDAT\xed\x9d1l]E\x16\x86\x0f\x85\x91(\x1cX,\x81E\xe1f\x15\xd8\x95((\xe9IE\x84(\x82\xd9\x02#YJ\xdcY\x18\x89TA\xa4\xdc\xa4\xb4hBA$\x02\x95\x8bE\n\x16\nB\xb1\x16\xb9\xa0H\\a,\xd1 \x11\xc4\x86\x02\xb9\xf1\x8a\x02C\xb4\x1bg\xd7O\xf6\xcd}3w\xee\xcc}\xe7\xcc\xcc\x87\x84\xfc\xde\x9d33g\xbe\xff\xccy\xbf\x12;~\xe4/\x7f\xfd\xf3\x7fd\x02\xff\xbd\xf8\xe2\x8b\xf2\xc1\x95+\x13\xd8\xc9\xbd\xc5\xcb\xa7O\xcb\xdd\xbbwGA\x9f]\xbf.sss\xf2\xce\xf9\xf3\xb2\xb1\xb1!\xe7\xce\x9e\x95\xe5\xe5e\xd9\xdc\xdc\x94\xb7VVFq\xbc\x88#\x80\xfeu\xf3\xb3\xa2\x7f\x9c\n\xcc\xae\xb5\x7fZ\xa9\xdfZ\xf9\xa7\xbay\x8f`x0<\xa9\x8a\xc9\xb5\x0e\r\xc3E\xc7?\x96;?+\xf9\xfbI\x13\xe1"P\xeb\x07\xae\x95\xfa\xad\x95\xbf\xab&C\xc60<\xfc\tOH\xbd\xf4\x8e\xa5a\xf4F\xf7`b\xee\xfc\xac\xe4\x1f\xa7\x02\xb3k\xfd\xc0\xb5R\xbf\xb5\xf2Ou\xf3\xaa7<_\xdc\xb8!\xb3\xb3\xb3\xf2\xde\xc5\x8b\xb2\xbe\xbe.o\xdf\xffk\xac\xc5\xc5E\xd9\xda\xda\x92sKK\xa98W\xbf\x8e\xd5\x86\x91\x8b\xfe\xb9\xf3\xb3\x92\x7f\xf5\x171\x12@\xf3\x037\x97\xfb\x13yl\xb1R\xbf\xb5\xf2\x8f\xd5\xefp\xfe\xc4\x0c\xcf\xe1\x86\xd6\xbe\xde\xbeuK\xa6\xa6\xa6\xe4\xa3k\xd7duu\xf5\xc1\xf7\x19\x1d\x14\xf7\xee\xee\xae\xbct\xea\x94\xb5t\xc9\'1\x01\xf4\x8f\x03\n\xbf8~\xb9\xcfF\x7f]\x05\xe1\x1f\xc6\xbfz\xc3\xb3q\xf3\xa6\xcc\xcc\xcc\xc8\xa5\xcb\x97emmM\xde\xbdpA\xe6\xe7\xe7eggG\xdeXX\x08\xa3Itv\x04\xd0?N2\xf8\xc5\xf1\xcb}6\xfa\xeb*\x08\xff0\xfe\xd5\x1b\x1e~J+\xac`J\x8bF\xff8E\xe1\x17\xc7/\xf7\xd9\xe8\xaf\xab \xfc\xc3\xf8cx\xf8\xa6\xe5\xb0\x8a),\x9a\x86\x11\'(\xfc\xe2\xf8\xe5>\x1b\xfdu\x15\x84\x7f\x18\x7f\x0c\x0f\x86\'\xacb\n\x8b\xa6a\xc4\t\n\xbf8~\xb9\xcfF\x7f]\x05\xe1\x1f\xc6\x7fb\x86\xe7\xe0\x1f\xf7{\xed\xcc\x99\xb0\xec\x8eD\x9f8qBN\x9e<)\xdb\xdb\xdb\xb2\xbf\xbf\x7fd$\xec\xe5\x87W\xaf\xca\xde\xde\xdeh\x12\x053B1\xe8\x0b\xf4\x8f\xc3\x0b\xbf8~\xb9\xcfF\x7f]\x05\xe1\xaf\xcb?\xd5\xee\x133<V\x7f\xac\x0f\xc3\x93\xaa\x94\xdc\xeb\xa0\xbf\x9b\x8fo\x14~>Be\x8f\xa3\xbf\xae\xbe\xf0\xd7\xe5\x9fjw\x0c\x0f\x7f\xa5\x95\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83\xf0\xf3"*:\x00\xfdu\xe5\x85\xbf.\xffT\xbbcx0<\xa9j\xc9\xb9\x0e\r\xc3\x89\xc7;\x08?/\xa2\xa2\x03\xd0_W^\xf8\xeb\xf2O\xb5;\x86\x07\xc3\x93\xaa\x96\x9c\xeb\xd00\x9cx\xbc\x83V\xf9}q\xe3\x86\xcc\xce\xce\xca{\x17/\xca\xfa\xfa\xba\xbc\xbd\xb2"\x8b\x8b\x8b\xb2\xb5\xb5%\xe7\x96\x96\xbc\xe7"\xa0\x1b\x01\xf4\xef\xc6i\xa8(\xf8\x0fEv\xb2\xebN\xcc\xf0L\xf6X\xddw\xfb\x0c\xc3\xd3\x1dV\x81\x91\xe8\x1f\'\xea\xed[\xb7djjJ>\xbavMVWW\xe5\x83+W\xe4\xe0\xc3awwW^:u*nqf\x9b\'\x80\xfe\xba\x12\xc1?\x8c\x7f\xf5\x86\xe7\xd5W_\x95\xe9\xe9i\xd9\xdc\xdc\x94\x1f\x7f\xfcQ\x9e\x7f\xfeyy\xe1\x85\x17\xe4_?\xfd$\xff\xfc\xea\xab0\x9aDgG\x00\xfd\xe3$\xdb\xb8ySfff\xe4\xd2\xe5\xcb\xb2\xb6\xb6&\xef^\xb8 \xf3\xf3\xf3\xb2\xb3\xb3#o,,\xc4-\xcel\xf3\x04\xd0_W"\xf8\x87\xf1\xaf\xde\xf0\x84\xe1"\x1a\x02\x108J\x80?!;J\xa3\xbe\xd7\xe8\xaf\xab9\xfc\xc3\xf8cx\xc2x\x11\r\x01\x08\x1c!@\xc3=\x02\xa3\xc2\x97\xe8\xaf+:\xfc\xc3\xf8cx\xc2x\x11\r\x01\x08\x1c!@\xc3=\x02\xa3\xc2\x97\xe8\xaf+:\xfc\xc3\xf8O\xcc\xf0\xcc\xcd\xcd\xc9kg\xce\x84ew$\xfa\xc4\x89\x13r\xf2\xe4I\xd9\xde\xde\x96\xfd\xfd\xfd##\xdd^2?\x8e\xdf!\xe5\x0f\xaf^\x95\xbd\xbd\xbd\xc3\xb7\x9d\xbf\xa2\x7f\x1c\x7f\xed\xfa=\x14\xba\xa9\x7f\xd7\x86\x8b\xfeu\xeb\x7fX?\xb9~\xd5\xae\xdfCn}\xef\xdf\xe1\xfc\xda\xbfN\xcc\xf0X\xf9\xb1\xbe\xda\x05\x8f=\xff\xcb\xa7O\xcb\xdd\xbbw\x83\x97A\xff`d&\'4\xf5\xefjx\xd0\xdf\xa4\x9c\xc1I\xf5\xd5?x#c\x13\xac\xd4o\xad\xfcS\x95\x03\x86\'\x15\xc9J\xd6i^\xb8\xae\xc7\xb6\xd20\xba\xe6K\\;\x81\xa6\xfe\x18\x9evN\xa5>\xed\xab\x7f\xee<\xac\xf4\xafZ\xf9\xa7\xaa\x1f\x0cO*\x92\x95\xac\xd3\xbcp]\x8fm\xa5at\xcd\x97\xb8v\x02M\xfd1<\xed\x9cJ}\xdaW\xff\xdcyX\xe9_\xb5\xf2OU?\x18\x9eT$+Y\xa7y\xe1\xba\x1e\xdbJ\xc3\xe8\x9a/q\xed\x04\x9a\xfacx\xda9\x95\xfa\xb4\xaf\xfe\xb9\xf3\xb0\xd2\xbfj\xe5\x9f\xaa~0<\xa9HV\xb2N\xf3\xc2u=\xb6\x95\x86\xd15_\xe2\xda\t4\xf5\xc7\xf0\xb4s*\xf5i_\xfds\xe7a\xa5\x7f\xd5\xca?U\xfd`xR\x91\xacd\x9d\xe6\x85\xebzl+\r\xa3k\xbe\xc4\xb5\x13h\xea\x8f\xe1i\xe7T\xea\xd3\xbe\xfa\xe7\xce\xc3J\xff\xaa\x95\x7f\xaa\xfa\xc1\xf0\xa4"Y\xc9:\xcd\x0b\xd7\xf5\xd8V\x1aF\xd7|\x89k\'\xd0\xd4\x1f\xc3\xd3\xce\xa9\xd4\xa7}\xf5\xcf\x9d\x87\x95\xfeU+\xffT\xf5\x83\xe1IE\xb2\x92u\x9a\x17\xae\xeb\xb1\xad4\x8c\xae\xf9\x12\xd7N\xa0\xa9?\x86\xa7\x9dS\xa9O\xfb\xea\x9f;\x0f+\xfd\xabV\xfe\xa9\xea\x07\xc3\x93\x8ad%\xeb4/\\\xd7c[i\x18]\xf3%\xae\x9d@S\x7f\x0cO;\xa7R\x9f\xf6\xd5?w\x1eV\xfaW\xad\xfcS\xd5\x0f\x86\'\x15\xc9J\xd6\xf9\xf8\x93O\xe4\xdf\x1d\xfe\xa5\xe5;\xf7\x7f\xf3\xfc\x97_~9\xa2b\xa5a\x8c\x12\xe2E/\x02}\x1b.\xfa\xf7\xc2mnR_\xfd\xcd\x1d$0!+\xf5[+\xff@\xb9\xc6\x86cx\xc6\xa2a \x86\xc0\xe6\xe6\xa6\xbc\xb5\xb22Z\xc2J\xc3\x18%\xc4\x8b^\x04\xfa6\\\xf4\xef\x85\xdb\xdc\xa4\xbe\xfa\x9b;H`BV\xea\xb7V\xfe\x81r\x8d\r\xc7\xf0\x8cE\xc3@\x1b\x81\x9f\x7f\xfeY\xee\xdd\xbb\xd76\xf4\xe0\xd9\xc1\xef|:\xf8\x1f\xc33\x16Q\xd6\x03}\x1b\xae\x95\x0f\x8c\xac\xe1\x1bH\xbe\xaf\xfe\x06R\x8fJ\xc1J\xfd\xd6\xca?J\xbc#\x931<G`\xf0\xd2O\xa0y\xe1\x9a3\xce\x9d=+\xcb\xcb\xcb\x18\x9e&\x98B\xde7\xf5\xe7{x\n\x11\xb6\xe31\xfa\xea\xdfqy\xb3a\x18\x1e\xb3\xd2\x04%\x86\xe1\t\xc2Ep\xb3\xe15\x89`x\x9aD\xcaz\xdf\xd4\x1f\xc3S\x96\xbe\xbe\xd3\xf4\xd5\xdf\xb7\xae\xf5q\x0c\x8fu\x85\xba\xe5\x87\xe1\xe9\xc6\x89\xa8\xff\x13\xf8\xee\xbb\xef\xe4\xf7\xdf\x7f\x7f\x88\xc7\xfb\xef\xbf/\xb7\xb7\xb6\x04\xc3\xf3\x10\x9a\xa2\x1e\xf4\xfd\xc0\xb3\xf2\x81Q\x94\x18\n\x87\xe9\xab\xbfB\xaaI\xb7\xb4R\xbf\xb5\xf2O%&\x86\'\x15\xc9\xca\xd7y\xe7\xfcy\xd9\xd8\xd8\xc0\xf0\x14^\x07}\x1b\xae\x95\x0f\x8c\xc2\xe5\x19\xfcx}\xf5\x1f<\xb1\x817\xb0R\xbf\xb5\xf2O%/\x86\'\x15\xc9J\xd6\xb9~\xfd\xba\xfc\xfa\xeb\xaf\xa3\xd3\xbe\xf2\xca+2==-\x18\x9e\x11\x92\xa2_\xf4m\xb8V>0\x8a\x16g\x02\x87\xeb\xab\xff\x04R\x1bt\x0b+\xf5[+\xffT\xe2bxR\x91\xacd\x9d\xbe\x17\xceJ\xc3\xa8D\xa6\xc1\x8e\x89\xfe\x83\xa1\xcdb\xe1\xbe\xfagq8G\x92V\xfaW\xad\xfc\x1d\xd2\x04\rax\x82p\x11\xdc\xf7\xc2Yi\x18(\x18G\x00\xfd\xe3\xf8\xe5>\xbb\xaf\xfe\xb9\x9f\xdbJ\xff\xaa\x95\x7f\xaa\xfa\xc1\xf0\xa4"Y\xc9:}/\x9c\x95\x86Q\x89L\x83\x1d\x13\xfd\x07C\x9b\xc5\xc2}\xf5\xcf\xe2p\x8e$\xad\xf4\xafZ\xf9;\xa4\t\x1a\xc2\xf0\x04\xe1"\xb8\xef\x85\xb3\xd20P0\x8e\x00\xfa\xc7\xf1\xcb}v_\xfds?\xb7\x95\xfeU+\xffT\xf5\x83\xe1IE\xb2\x92u\xfa^8+\r\xa3\x12\x99\x06;&\xfa\x0f\x866\x8b\x85\xfb\xea\x9f\xc5\xe1\x1cIZ\xe9_\xb5\xf2wH\x134\x84\xe1\t\xc2Ep\xdf\x0bg\xa5a\xa0`\x1c\x01\xf4\x8f\xe3\x97\xfb\xec\xbe\xfa\xe7~n+\xfd\xabV\xfe\xa9\xea\x07\xc3\x93\x8ad%\xeb\xf4\xbdpV\x1aF%2\rvL\xf4\x1f\x0cm\x16\x0b\xf7\xd5?\x8b\xc39\x92\xb4\xd2\xbfj\xe5\xef\x90&h\x08\xc3\x13\x84\x8b\xe0\xbe\x17\xceJ\xc3@\xc18\x02\xe8\x1f\xc7/\xf7\xd9}\xf5\xcf\xfd\xdcV\xfaW\xad\xfcS\xd5\x0f\x86\'\x15\xc9J\xd6\xe9{\xe1\xac4\x8cJd\x1a\xec\x98\xe8?\x18\xda,\x16\xee\xab\x7f\x16\x87s$i\xa5\x7f\xd5\xca\xdf!M\xd0\x10\x86\'\x08\x17\xc1}/\x9c\x95\x86\x81\x82q\x04\xd0?\x8e_\xee\xb3\xfb\xea\x9f\xfb\xb9\xad\xf4\xafZ\xf9\xa7\xaa\x1f\x0cO*\x92\x95\xac\xd3\xbcp_\xdc\xb8!\xb3\xb3\xb3\xf2\xde\xc5\x8b\xb2\xbe\xbe.o\xaf\xac\xc8\xe2\xe2\xa2l\x1d\xfc"\xd1\xa5\xa5\x11\x15+\rc\x94\x10/z\x11@\xff^\xd8\x8a\x99\xd4W\xff\xdc\x01X\xe9_\xb5\xf2OU?\x133<\xe3\x12\xfe\xec\xfe\xeff\x9a\x9b\x9b\xf3\xfe.\xa6q\xf3y\xaeK\xe0\xf6\xad[255%\x1f]\xbb&\xab\xab\xab\xf2\xc1\x95+r\xd0\x1cvww\xe5\xa5S\xa7\xbc\xc9\xa1\xbf\x17\x91\xe9\x00\xf47-\xcf\xe0\xc9\xc5\xea?x\x82\x03o\xa0\xdd\xbfj\xe7\x1f*/\x86\'\x94\x18\xf1\xc7\x08l\xdc\xbc)333r\xe9\xf2eY[[\x93w/\\\x90\xf9\xf9y\xd9\xd9\xd9\x917\x16\x16\x8e\xc5\xb6\xbd\xd1n\x18m9\xf1\xac;\x01\xf4\xef\xce\xaa\xc4\xc8X\xfdsg\xa2\xdd\xbfj\xe7\x1fZ?\x18\x9ePb\xc4\x1f#\x10{\xe1c\xe7\x1fK\x867\x13\'\x10\xab_\xec\xfc\x89\x1f\x98\r\x8f\x11\xa8]?\xed\xf3k\xef\x7f\xac\x182x\x83\xe1\xc9@$\xcb)\xc6^\xb8\xd8\xf9\x96\xd9\xd4\x90[\xac~\xb1\xf3k`l\xf9\x8c\xb5\xeb\xa7}~\xed\xfd-\xd7f[n\x18\x9e6*<\xebL \xf6\xc2\xc5\xce\xef\x9c(\x81\x83\x10\x88\xd5/v\xfe \x87b\xd1\xce\x04j\xd7O\xfb\xfc\xda\xfbw.\x14#\x81\x18\x1e#B\xe4\x9aF\xec\x85\x8b\x9d\x9f+\xb7R\xf2\x8e\xd5/v~)\x1cs=G\xed\xfai\x9f_{\xff\xdc\xea\x16\xc3\x93\x9bb\xc6\xf2\x8d\xbdp\xb1\xf3\x8d\xe1\xa8.\x9dX\xfdb\xe7W\x07\xdc\xd8\x81k\xd7O\xfb\xfc\xda\xfb\x1b+Go:\x18\x1e/"\x02\\\x04b/\\\xec|Wn\x8c\rO V\xbf\xd8\xf9\xc3\x9f\x90\x1d\\\x04j\xd7O\xfb\xfc\xda\xfb\xbbj\xc3\xe2\x18\x86\xc7\xa2*\x19\xe5\x14{\xe1b\xe7g\x84\xaa\xc8Tc\xf5\x8b\x9d_$\xd4\x8c\x0eU\xbb~\xda\xe7\xd7\xde?\xa3R}\x90*\x86\'7\xc5\x8c\xe5\x1b{\xe1b\xe7\x1b\xc3Q]:\xb1\xfa\xc5\xce\xaf\x0e\xb8\xb1\x03\xd7\xae\x9f\xf6\xf9\xb5\xf77V\x8e\xdet0<^D\x04\xb8\x08\xc4^\xb8\xd8\xf9\xae\xdc\x18\x1b\x9e@\xac~\xb1\xf3\x87?!;\xb8\x08\xd4\xae\x9f\xf6\xf9\xb5\xf7w\xd5\x86\xc51\x0c\x8fEU2\xca)\xf6\xc2\xc5\xce\xcf\x08U\x91\xa9\xc6\xea\x17;\xbfH\xa8\x19\x1d\xaav\xfd\xb4\xcf\xaf\xbd\x7fF\xa5\xfa U\x0cOn\x8a\x19\xcb7\xf6\xc2\xc5\xce7\x86\xa3\xbatb\xf5\x8b\x9d_\x1dpc\x07\xae]?\xed\xf3k\xefo\xac\x1c\xbd\xe9`x\xbc\x88\x08p\x11\x88\xbdp\xb1\xf3]\xb916<\x81X\xfdb\xe7\x0f\x7fBvp\x11\xa8]?\xed\xf3k\xef\xef\xaa\r\x8bc\x18\x1e\x8b\xaad\x94S\xec\x85\x8b\x9d\x9f\x11\xaa"S\x8d\xd5/v~\x91P3:T\xed\xfai\x9f_{\xff\x8cJ\xf5A\xaaf\r\xcf\x0f?\xfc \x9f\x7f\xfe\xf9\x88\xe7\xf4\xf4\xb4<\xf7\xdcs\xf2\xcd7\xdf\xc8\xfe\xfe\xfe\xe8y\xd7\x17\xcc\x1f\x86\xdf\xc2\xfd\xdf\x88\xfe\xf8\xe3\x8f\xcb;\xe7\xcf\xcb\xc6\xc6\x86\x9c;{V\x96\x97\x97essS\xdeZY\xf1\xca3\xee\xc2\xa2\xffqtV\xeb\x17\xfd\x8f\xeb4\xee\x9dU\xfd\xc6\xe5\xdb|>.\xffX\xfd\x9b\xfb\xe4\xf6^\xbb\x7f\xd5\xce?\xb4^\xcc\x1a\x9e\xd0\x83\x10\xafK \xb5\xe1\xd1=\r\xbb\x87\x12@\xffPbe\xc5\xf7\xd5?w\n\xe3\x0c\xcf\xa4\xcfU+\xffP\xce\xe6\x0c\xcf\xdf^\x7f]\xde|\xf3\xcd\x87\xce\xf1\xe8\xa3\x8f\xca\x93O>)\xbf\xfc\xf2\x8b\xdc\xbbw\xef\xa1q\xdf\x03\xe6\x0f\xcb\xef\xef\x97.\xc9\xd7_\x7f\x1d\xfd\'<\xe8\xdf^\xc9\xd6\xeb\x17\xfd\xdbu;|j]\xbf\xc3<\xc7}\xf5\xe5\xdfW\xffq\xfb\xe5\xf2\xbcix\xb4\xfaW\xad\xfcC\xeb\xc4\x9c\xe1\t=\x00\xf1\xb6\x08\xc4\xfe\x95\x96\xad\xd3\x90M(\x01\xf4\x0f%VV|\xa8\xfe\xb9\x9f\xbeix\xb4\xcfS\x1b\xffP\xde\x18\x9ePb\xc4;\t\x84^8k\r\xc3y8\x06\xbd\x04\xd0\xdf\x8b\xa8\xe8\x80P\xfds\x87a\xad\x7f\xd5\xc6?\xb4~\xcc\x18\x9e;w\xee\xc8\xde\xde\xde\xd8\xfc\x1f{\xec1y\xe6\x99g\xe4 \xee\x8f?\xfe\x18\x1b7n\x80\xf9\x93\xe1\xf7\xd4SO\xc9\xd3O?\x1d\xfcM\xcb\xe8?\xaer\xff\xf7<\x97\xfaE\xffv\x1ds\xd1\xaf={\x91\xae\xf9\x87\xea?n\xbf\\\x9e\x1f\x1a\x1e+\xfd\xab6\xfe\xa1ub\xc6\xf0\x84&N\xbcm\x02\xa1?\xa5e\xfb4d\x17J\x00\xfdC\x89\x95\x15\xdfU\xff\xdcO}hx\xac\x9d\xa3\x16\xfe\xa1\xdc\xd5\r\xcf\xd2\xd2\x92\xfc\xe9\x89\'\xbcy\x1f\xfcX\xe4\xb3\xcf>+\xdb\xdf~+\xfb\xbf\xfd\xe6\x8do\x060\x7f\xb2\xfc\xbe\xff\xfe{\xf9\xc7\xa7\x9f6ex\xe8=\xfa?\x84\xa4\xf5An\xf5\x8b\xfe\xc7e\xccM\xbf\xe3\xd9\x8b\x84\xe6\xdfU\xff\xe6>\xb9\xbd\xb7\xda\xbfj\xe1\x1fZ/\xea\x86\'4a\xe2!\x00\x01\x08@\x00\x02\x10\x80@(\x01\x0cO(1\xe2!\x00\x01\x08@\x00\x02\x10\xc8\x8e\x00\x86\';\xc9H\x18\x02\x10\x80\x00\x04 \x00\x81P\x02\x18\x9ePb\xc4C\x00\x02\x10\x80\x00\x04 \x90\x1d\x01\x0cOv\x92\x910\x04 \x00\x01\x08@\x00\x02\xa1\x040<\xa1\xc4\x88\x87\x00\x04 \x00\x01\x08@ ;\x02\x18\x9e\xec$#a\x08@\x00\x02\x10\x80\x00\x04B\t`xB\x89\x11\x0f\x01\x08@\x00\x02\x10\x80@v\x040<\xd9IF\xc2\x10\x80\x00\x04 \x00\x01\x08\x84\x12\xc0\xf0\x84\x12#\x1e\x02\x10\x80\x00\x04 \x00\x81\xec\x08`x\xb2\x93\x8c\x84!\x00\x01\x08@\x00\x02\x10\x08%\x80\xe1\t%F<\x04 \x00\x01\x08@\x00\x02\xd9\x11\xc0\xf0d\'\x19\tC\x00\x02\x10\x80\x00\x04 \x10J\x00\xc3\x13J\x8cx\x08@\x00\x02\x10\x80\x00\x04\xb2#\x80\xe1\xc9N2\x12\x86\x00\x04 \x00\x01\x08@ \x94\x00\x86\'\x94\x18\xf1\x10\x80\x00\x04 \x00\x01\x08dG\x00\xc3\x93\x9dd$\x0c\x01\x08@\x00\x02\x10\x80@(\x01\x0cO(1\xe2!\x00\x01\x08@\x00\x02\x10\xc8\x8e\x00\x86\';\xc9H\x18\x02\x10\x80\x00\x04 \x00\x81P\x02\x18\x9ePb\xc4C\x00\x02\x10\x80\x00\x04 \x90\x1d\x01\x0cOv\x92\x910\x04 \x00\x01\x08@\x00\x02\xa1\x040<\xa1\xc4\x88\x87\x00\x04 \x00\x01\x08@ ;\x02\xff\x05\xef\xdbu\x9c\x91!t\x7f\x00\x00\x00\x00IEND\xaeB`\x82'
testurl = 'https://i.pximg.net/img-master/img/2010/02/21/00/03/29/8913281_p0_master1200.jpg'

# goodUsers = open(os.path.join(module_path, 'users.txt')).readlines()
goodUsers = [2188232,8301448,159912,2538693,2369321,490219,177784,29942,67388,341433,170125,84644,21848,37062,141206,1565632,1980643,21848,3869665,1014350,60811980,10302,714577,9678597,23353614,2573035,23174275,22874219,1468214,39852592,5599364,201323,27997632,2336561,14068082,31850232,106493,14793912,2363169,29886428,20228000,18433206,1194280,9384575,74892,154324,111243,40378966,54749,9685977,8445925,17648188,2442597,2362990,2782928,31731060,2744600,3367474,1464339,237082,8843541,33844486,1568424,26876630,6437284,14609740,42218006,356998,192782,6191718,942719,14592593,431592,14561023,45833,1198521,6965885,17334809,4426993,48434,13409,4314826,3806145,4035447,231279,33590509,13430462,333556,6341514,320757,1250474,316471,72575877,21230641,159905,2874136,3259336]

host	= 'https://api.imjad.cn/pixiv/v1/'
host2	= 'https://api.imjad.cn/pixiv/v2/'

headers = {
	'user-agent':'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.122 Safari/537.36',
	'referer':'https://www.pixiv.net/',
	'host':'www.pixiv.net'
}

class Pixiv:
	def __init__(self, results, translate=0):
		self.results	= results
		self.response	= self.results['response'][0]
		self.title		= self.response['title']
		self.caption	= self.response['caption']
		self.tags		= self.response['tags']
		self.stats		= self.response['stats']
		self.image_urls	= self.response['image_urls']
		self.px_128x128	= self.image_urls['px_128x128']
		self.px_480mw	= self.image_urls['px_480mw']
		self.small		= self.image_urls['small']
		self.medium		= self.image_urls['medium']
		self.large		= self.image_urls['large']
		self.width		= self.response['width']
		self.height		= self.response['height']
		self.time       = self.response['created_time']
		self.last_time	= self.response['reuploaded_time']
		self.age_limit	= self.response['age_limit']
		self.user		= self.response['user']
		self.id_		= self.user['id']
		self.account	= self.user['account']
		self.name		= self.user['name']
		self.avartar	= self.user['profile_image_urls']['px_50x50']
		self.profile	= self.user['profile']
		self.is_manga	= self.response['is_manga']
		self.manga		= []
		if self.is_manga:
			self.pages	= self.response['metadata']['pages']
			for page in self.pages:
				self.manga.append(page['image_urls']['large'])
		if translate:
			self.title		= yd.translate(words = self.response['title'])
			self.caption	= yd.translate(words = self.response['caption'])
			self.tags		= yd.translate_list(words = self.response['tags'])

class User:
	def __init__(self, response):
		self.id_		= response['user']['id']
		self.account	= response['user']['account']
		self.name		= response['user']['name']
		self.avartar	= response['user']['profile_image_urls']['medium']
		self.is_premium	= response['profile']['is_premium']
		self.illusts	= response['profile']['total_illusts']
		self.manga		= response['profile']['total_manga']
		self.novels		= response['profile']['total_novels']
		self.webpage	= response['profile']['webpage']
		self.gender		= response['profile']['gender']
		self.region		= response['profile']['region']
		self.code		= response['profile']['country_code']
		self.twitter	= response['profile']['twitter_url']
		self.pawoo		= response['profile']['pawoo_url']

def getImg_old(url = 0, name = 0, path = './', type_ = 'jpg', id_ = 0, setting = 'large', useCurl = 0):
	if url:
		if not name:
			name_ = str(simplim.tuple2str(simplim.localtime(6)))
		else:
			name_ = str(name)
		path_ = os.path.join(path, simplim.standardfile(name_) + '.' + type_)
		if not Path(path).exists():
			os.mkdir(path)
			print('[N] mkdir successed')
		if useCurl:
			os.system('curl --header "referer: https://www.pixiv.net/" -o '+ path_ + ' ' + url)
		else:
			img = rq.get(url, stream = True, headers = headers)
			length = float(img.headers['content-length'])
			length_M = length / 1000 / 1000
			length_M_str = str(length_M)[:4]
			count = 0
			count_tmp = 0
			delta = 0.5
			cnt = 0
			time1 = time.time()
			with open(path_, 'ab') as f:
				for chunk in img.iter_content(chunk_size = 512):
					if chunk:
						f.write(chunk)
						f.flush()
						count += len(chunk)
						if time.time() - time1 > delta:
							percent = count / length * 100
							num = int(percent / 2)
							speed_raw = (count - count_tmp)/delta
							speed = (count - count_tmp) / 1000 / 1000 / delta
							count_tmp = count
							left = str(int((length-count)/speed_raw))
							print('\r' + num*'█' + (50-num)*' ' + str(percent)[:4] + '% ' + str(speed)[:4] + 'M/s ' + length_M_str +'M ' + left + 's   ',end='',flush=True)
							time1 = time.time()
				f.close()
		print('\n','[N]',str(name_) + '.' + type_, 'successfully downloaded')
	else:
		results, processed = getInfo(id_ = id_)
		if results == None:
			return
		image_urls = processed.image_urls
		if not name:
			name = processed.title
		getImg(url = image_urls[setting], name = name, path = path, type_ = type_, setting = setting, useCurl = useCurl)

def getImg(url = 0, name = 0, path = './', type_ = 'jpg', id_ = 0, setting = 'large', useCurl = 0):
	if url:
		if not name:
			name_ = str(simplim.tuple2str(simplim.localtime(6)))
		else:
			name_ = str(name)
		path_ = os.path.join(path, simplim.standardfile(name_) + '.' + type_)
		if not Path(path).exists():
			os.mkdir(path)
			print('[N] mkdir successed')
		if useCurl:
			os.system('curl --header "referer: https://www.pixiv.net/" -o '+ path_ + ' ' + url)
		else:
			img = simplim.download(url, headers = headers, delta_time = 0.1)
			f = open(path_, 'ab')
			f.write(img.getvalue())
			f.close()
		print('\n','[N]',str(name_) + '.' + type_, 'successfully downloaded')
		return
	else:
		results, processed = getInfo(id_ = id_)
		if results == None:
			return
		image_urls = processed.image_urls
		if not name:
			name = processed.title
		getImg(url = image_urls[setting], name = name, path = path, type_ = type_, setting = setting, useCurl = useCurl)

def getImg_raw(url = 0, id_ = 0, setting = 'large'):
	if url:
		print('[N]','start to get content')
		try:
			img = rq.get(url, headers = headers)
			raw = img.content
			print('[N]','successfully got content')
			return raw
		except :
			print('[E]','something went wrong')
	if id_:
		try:
			results, processed = getInfo(id_=id_)
			if results['status'] == 'success':
				image_urls = processed.image_urls
			raw = getImg_raw(url = image_urls[setting], setting = setting)
			return raw
		except:
			print('[E]','something went wrong')
	return lost

def getImg_raw_test(url = 0, id_ = 0, setting = 'large'):
	if url:
		print('[N]','start to get content')
		try:
			img = simplim.download(url, headers = headers, delta_time = 0.5)
			raw = img.getvalue()
			print('[N]','successfully got content')
			return raw
		except :
			print('[E]','something went wrong')
	if id_:
		try:
			results, processed = getInfo(id_=id_)
			if results['status'] == 'success':
				image_urls = processed.image_urls
			raw = getImg_raw(url = image_urls[setting], setting = setting)
			return raw
		except:
			print('[E]','something went wrong')
	return lost

def getImg_raw_flex(url = 0, id_ = 0, setting = 'large', object_ = None, delta_time = 1):
	if url:
		img = simplim.download(url, headers = headers, delta_time = delta_time, object_ = object_)
		if not img:
			return 0
		return img.getvalue()
	else:
		results, processed = getInfo(id_ = id_)
		if results == None:
			return
		image_urls = processed.image_urls
		return getImg_raw_flex(url = image_urls[setting], setting = setting, object_ = object_, delta_time = delta_time)

def getImgList(idList, path = 'pixiv_temp', type_ = 'jpg',setting = 'large', useCurl = 0):
	for id_ in idList:
		try:
			id_[7]
			int(id_)
			getInfo(id_)
		except:
			continue
		getImg(id_ = id_, path = path, type_ = type_, setting = setting, useCurl = useCurl)

def getImgList_raw(idList, path = 'pixiv_temp',type_ = 'jpg',setting = 'large',useCurl = 0):
	rawList = []
	for id_ in idList:
		raw = getImg_raw(id_ = id_, setting = setting)
		rawList.append(raw)
	return rawList


def getInfo(id_, translate=0):
	params	= {
		'type': 'illust',
		'id':id_
	}
	results	= rq.post(url = host, params = params).json()
	print(results)
	# print(results)
	if results['status'] == 'success':
		processed = Pixiv(results, translate)
		return results, processed
	else:
		print('[E] Failed!')
		return None, None
	# with open('info.txt','w') as fp:
	# 	json.dump(results, fp, indent=2)
	# print(rq.post(url=host, params=params).url)
	# print(type(results),'||',results)

def getManga(id_, path = './', type_ = 'jpg', setting = 'large', useCurl = 0):
	results, processed = getInfo(id_)
	path = os.path.join(path, simplim.standardfile(processed.title))
	page = 1
	for manga in processed.manga:
		getImg(url = manga, name = str(page), path = path, type_ = type_, useCurl = useCurl)
		page += 1

def getResponseId(response):
	idList = []
	for res in response:
		idList.append(int(res['id']))
	return idList

def getRankId(response):
	idList = []
	for res in response[0]['works']:
		idList.append(int(res['work']['id']))
	return idList

def getSearchImg(word, setting = 'small', path = './', mode = 'tags', order = 'desc', period = 'all', page = 1, per_page = 30):
	
	getImgList(getResponseId(search(word, mode = mode, order = order, period = period, page = page, per_page = per_page)), setting = setting, path = path)

def getUserInfo(id_):
	params	= {
		'type': 'member',
		'id': id_
	}
	results	= rq.post(url = host2, params = params).json()
	results['profile_publicity'] = ''
	results['workspace'] = ''
	try:
		return simplim.easyclassify(results)
	except:
		print('[E]','class failed')
		return results

def getUserWorks(id_, period = 'all', page = 1, per_page = 30):
	params	= {
		'type': 'member_illust',
		'id': id_,
		'period': period,
		'page': page,
		'per_page': per_page
	}
	results	= rq.post(url = host, params = params).json()
	if results['status'] == 'success':
		return getResponseId(results['response'])

def search(word, mode = 'tags', order = 'desc', period = 'all', page = 1, per_page = 30):
	params	= {
		'type': 'search',
		'word': word,
		'mode': mode,
		'order': order,
		'period': period,
		'page': page,
		'per_page': per_page
	}
	results	= rq.post(url = host, params = params).json()
	if results['status'] == 'success':
		return getResponseId(results['response'])
	else:
		return -1

def rank(mode = 'daily',date = ''):
	params	= {
		'type': 'rank',
		'mode': mode,
		'date': date
	}
	results	= rq.post(url = host, params = params).json()
	if results['status'] == 'success':
		return getRankId(results['response'])
	else:
		return -1

def randomGoodUserId():

	return int(goodUsers[random.randint(0, len(goodUsers))][:-1])

def randomGoodUserWorkId():
	works = getUserWorks(randomGoodUserId())
	return int(works[random.randint(0, len(works))])


















import inspect, random, json, math, threading, inspect, ctypes
 
 
def _async_raise(tid, exctype):
	"""raises the exception, performs cleanup if needed"""
	tid = ctypes.c_long(tid)
	if not inspect.isclass(exctype):
		exctype = type(exctype)
	res = ctypes.pythonapi.PyThreadState_SetAsyncExc(tid, ctypes.py_object(exctype))
	if res == 0:
		raise ValueError("invalid thread id")
	elif res != 1:
		# """if it returns a number greater than one, you're in trouble,
		# and you should call it again with exc=NULL to revert the effect"""
		ctypes.pythonapi.PyThreadState_SetAsyncExc(tid, None)
		raise SystemError("PyThreadState_SetAsyncExc failed")


def stop_thread(thread):
	_async_raise(thread.ident, SystemExit)

class empty:
	def __init__(self):
		pass
		

class list(list):
	"""docstring for list"""
	def __init__(self, arg = []):
		super(list, self).__init__(arg)
	def swap(self, a, b):
		x = self[a]
		self[a] = self[b]
		self[b] = x
		return self
	def shuffle(self, times = 100):
		for time in range(0, times):
			a = random.randint(0, self.length-1)
			b = random.randint(0, self.length-1)
			self.swap(a, b)
		return self
	def subscriptable(self, arg):
		if type(arg) == type([]) or type(arg) == type(list([])):
			return True
		return False
	def have(self, arg):
		for value in self:
			if arg == value:
				return True
			elif self.subscriptable(value):
				value = list(value)
				if value.have(arg):
					return True
		return False
	def isempty(self):
		if len(self) == 0:
			return True
		return False


class str(str):
	"""docstring for str"""
	def __init__(self, arg = ''):
		super(str, self).__init__()
	def reverse(self):
		index = -1
		ret = ''
		for char in self:
			ret += self[index]
			index -= 1
		self = ret
		return ret
	def belongto(self, symbols):
		if len(self) != 1:
			return False
		for symbol in symbols:
			if self == symbol:
				return True
		return False
	def isnumber(self):
		try:
			float(self)
		except:
			return False
		else:
			return True

class simdict(dict):
	def __init__(self, dict_, check = True):
		if type(dict_) == type(''):
			dict_ = json.load(open(dict_))
		super().__init__(dict_)
		self.__seed__ = 0
		if type(dict_) != type(dict()):
			print('failed to convert data to simdict')
			return
		try:
			for key in dict_:
				# print(key, dict_[key])
				if type(dict_[key]) == type(dict()):
					obj = simdict(dict_[key])
				else:
					obj = dict_[key]
				key = self.check(key)
				exec('self.'+key+' = obj')
		except Exception as e:
			raise e
			print('please make sure your json keys are legal variable')
		self.__vars__ = sorted(vars(self))[1:]
		self.dict_ = dict_
		# self.__varnum__ = len(self.__vars__)
	def check(self, key):
		try:
			exec(key+' = None')
		except:
			tmp = '_sd'+ str(self.__seed__)
			self.__seed__ += 1
			# print(key,'has been modified to',tmp)
			return tmp
		else:
			return key
	def get(self, key):
		if type(key) == int:
			key = self.__vars__[key]
			exec('self.ret = self.'+key)
			return self.ret
		elif type(key) == str:
			return self[key]
	def dump(self, path, indent = 4):
		open(path,'w').write(self.output(indent = indent))
	def output(self, indent = 4):
		return json.dumps(self, indent = indent)
	def __keys__(self):
		for key in self:
			print(key)
	# def __getitem__(self, key):
	# 	if type(self.dict_[key]) == str:
	# 		return self.dict_[key]
	# 	return simdict(self.dict_[key])


class Thread(threading.Thread):
	"""docstring for Thread"""
	def __init__(self, arg):
		super(Thread, self).__init__()
	def stop(self):
		thread.stop_thread(self)




		


from subprocess import call
import os
# osascript -e "display notification \"test\" with title \"title\" sound name \"Blow\" "
def notify(title="Notificaton", content='content', subtitle='subtitle', sound=''):
	cmd = 'display notification "' + content + '" with title "' + title + '" ' + 'subtitle ' + '"' + subtitle + '" ' 
	if sound:
		if os.path.exists(sound):
			call(["osascript", "-e", cmd])
			call(['play', '-q', sound])
			return
		if sound == 'default':
			cmd+='sound name ' + '""'
		else:
			cmd+='sound name ' + '"' + sound + '"'
	call(["osascript", "-e", cmd])


def dialog(title='Dialog', content='content', subtitle='subtitle'):
	cmd = 'display dialog "' + content + '" with title "' + title + '" '
	x=call(['osascript', '-e', cmd])
	return not bool(x)

def run(cmd):
	call(['osascript','-e',cmd])